@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct Accounts {
-    client: Client,
+    pub client: Client,
 }
 
 impl Accounts {
@@ -42,24 +42,18 @@ impl Accounts {
         page_number: i64,
         next_page_token: &str,
     ) -> Result<crate::types::Domains> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !next_page_token.is_empty() {
-            query_args.push(format!("next_page_token={}", next_page_token));
+            query_args.push(("next_page_token".to_string(), next_page_token.to_string()));
         }
         if page_number > 0 {
-            query_args.push(format!("page_number={}", page_number));
+            query_args.push(("page_number".to_string(), page_number.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
+            query_args.push(("page_size".to_string(), page_size.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/accounts?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/accounts?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -81,16 +75,13 @@ impl Accounts {
      *
      *  
      */
-    pub async fn account_create(
+    pub async fn create(
         &self,
         body: &crate::types::AccountCreateRequest,
     ) -> Result<crate::types::AccountCreateResponse> {
         let url = "/accounts".to_string();
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -146,7 +137,7 @@ impl Accounts {
      *
      * * `account_id: &str` -- User's first name.
      */
-    pub async fn account_disassociate(&self, account_id: &str) -> Result<()> {
+    pub async fn disassociate(&self, account_id: &str) -> Result<()> {
         let url = format!(
             "/accounts/{}",
             crate::progenitor_support::encode_path(&account_id.to_string()),
@@ -176,7 +167,7 @@ impl Accounts {
      *
      * * `account_id: &str` -- User's first name.
      */
-    pub async fn account_options_update(
+    pub async fn options_update(
         &self,
         account_id: &str,
         body: &crate::types::Options,
@@ -187,10 +178,7 @@ impl Accounts {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -222,28 +210,27 @@ impl Accounts {
      *   
      *   To use multiple values, comma-separate each value. For example: `host_video,participant_video`.
      */
-    pub async fn account_settings_domains(
+    pub async fn settings_domains(
         &self,
         account_id: &str,
         option: crate::types::OptionData,
         custom_query_fields: &str,
     ) -> Result<crate::types::Domains> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !custom_query_fields.is_empty() {
-            query_args.push(format!("custom_query_fields={}", custom_query_fields));
+            query_args.push((
+                "custom_query_fields".to_string(),
+                custom_query_fields.to_string(),
+            ));
         }
-        query_args.push(format!("option={}", option));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !option.to_string().is_empty() {
+            query_args.push(("option".to_string(), option.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/accounts/{}/settings?{}",
             crate::progenitor_support::encode_path(&account_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -277,28 +264,27 @@ impl Accounts {
      *   
      *   To use multiple values, comma-separate each value. For example: `host_video,participant_video`.
      */
-    pub async fn account_settings_security(
+    pub async fn settings_security(
         &self,
         account_id: &str,
         option: crate::types::OptionData,
         custom_query_fields: &str,
     ) -> Result<crate::types::Security> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !custom_query_fields.is_empty() {
-            query_args.push(format!("custom_query_fields={}", custom_query_fields));
+            query_args.push((
+                "custom_query_fields".to_string(),
+                custom_query_fields.to_string(),
+            ));
         }
-        query_args.push(format!("option={}", option));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !option.to_string().is_empty() {
+            query_args.push(("option".to_string(), option.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/accounts/{}/settings?{}",
             crate::progenitor_support::encode_path(&account_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -332,28 +318,27 @@ impl Accounts {
      *   
      *   To use multiple values, comma-separate each value. For example: `host_video,participant_video`.
      */
-    pub async fn account_settings(
+    pub async fn settings_account(
         &self,
         account_id: &str,
         option: crate::types::OptionData,
         custom_query_fields: &str,
     ) -> Result<crate::types::AccountSettings> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !custom_query_fields.is_empty() {
-            query_args.push(format!("custom_query_fields={}", custom_query_fields));
+            query_args.push((
+                "custom_query_fields".to_string(),
+                custom_query_fields.to_string(),
+            ));
         }
-        query_args.push(format!("option={}", option));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !option.to_string().is_empty() {
+            query_args.push(("option".to_string(), option.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/accounts/{}/settings?{}",
             crate::progenitor_support::encode_path(&account_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -387,28 +372,27 @@ impl Accounts {
      *   
      *   To use multiple values, comma-separate each value. For example: `host_video,participant_video`.
      */
-    pub async fn account_settings_meeting_security(
+    pub async fn settings_meeting_security(
         &self,
         account_id: &str,
         option: crate::types::OptionData,
         custom_query_fields: &str,
     ) -> Result<crate::types::MeetingSecuritySettings> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !custom_query_fields.is_empty() {
-            query_args.push(format!("custom_query_fields={}", custom_query_fields));
+            query_args.push((
+                "custom_query_fields".to_string(),
+                custom_query_fields.to_string(),
+            ));
         }
-        query_args.push(format!("option={}", option));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !option.to_string().is_empty() {
+            query_args.push(("option".to_string(), option.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/accounts/{}/settings?{}",
             crate::progenitor_support::encode_path(&account_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -442,28 +426,27 @@ impl Accounts {
      *   
      *   To use multiple values, comma-separate each value. For example: `host_video,participant_video`.
      */
-    pub async fn account_setting(
+    pub async fn setting(
         &self,
         account_id: &str,
         option: crate::types::OptionData,
         custom_query_fields: &str,
     ) -> Result<crate::types::AccountSettingsResponseOneOf> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !custom_query_fields.is_empty() {
-            query_args.push(format!("custom_query_fields={}", custom_query_fields));
+            query_args.push((
+                "custom_query_fields".to_string(),
+                custom_query_fields.to_string(),
+            ));
         }
-        query_args.push(format!("option={}", option));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !option.to_string().is_empty() {
+            query_args.push(("option".to_string(), option.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/accounts/{}/settings?{}",
             crate::progenitor_support::encode_path(&account_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -486,32 +469,25 @@ impl Accounts {
      * * `account_id: &str` -- User's first name.
      * * `option: crate::types::AccountSettingsUpdateOption`
      */
-    pub async fn account_settings_update(
+    pub async fn settings_update(
         &self,
         account_id: &str,
         option: crate::types::AccountSettingsUpdateOption,
         body: &crate::types::AccountSettingsUpdateRequestOneOf,
     ) -> Result<()> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("option={}", option));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !option.to_string().is_empty() {
+            query_args.push(("option".to_string(), option.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/accounts/{}/settings?{}",
             crate::progenitor_support::encode_path(&account_id.to_string()),
-            query
+            query_
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -538,10 +514,7 @@ impl Accounts {
      *
      * * `account_id: &str` -- Unique Identifier of the account. To retrieve locked settings of the master account or a regular account, provide "me" as the value of this field. <br> To retrieve locked settings of a sub account, provide the Account ID of the sub account in this field.
      */
-    pub async fn account_managed_domain(
-        &self,
-        account_id: &str,
-    ) -> Result<crate::types::DomainsList> {
+    pub async fn managed_domain(&self, account_id: &str) -> Result<crate::types::DomainsList> {
         let url = format!(
             "/accounts/{}/managed_domains",
             crate::progenitor_support::encode_path(&account_id.to_string()),
@@ -566,7 +539,7 @@ impl Accounts {
      *
      * * `account_id: &str` -- User's first name.
      */
-    pub async fn account_trusted_domain(
+    pub async fn trusted_domain(
         &self,
         account_id: &str,
     ) -> Result<crate::types::AccountTrustedDomainResponse> {
@@ -611,30 +584,27 @@ impl Accounts {
      *   }
      *   <br>You can provide multiple values by separating them with commas(example: "host_video,participant_video”).
      */
-    pub async fn get_account_lock_setting(
+    pub async fn get_lock_setting(
         &self,
         account_id: &str,
         option: &str,
         custom_query_fields: &str,
     ) -> Result<crate::types::Domains> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !custom_query_fields.is_empty() {
-            query_args.push(format!("custom_query_fields={}", custom_query_fields));
+            query_args.push((
+                "custom_query_fields".to_string(),
+                custom_query_fields.to_string(),
+            ));
         }
         if !option.is_empty() {
-            query_args.push(format!("option={}", option));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("option".to_string(), option.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/accounts/{}/lock_settings?{}",
             crate::progenitor_support::encode_path(&account_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -661,7 +631,7 @@ impl Accounts {
      *
      * * `account_id: &str` -- Unique Identifier of the account. To retrieve locked settings of the master account or a regular account, provide "me" as the value of this field. <br> To retrieve locked settings of a sub account, provide the Account ID of the sub account in this field.
      */
-    pub async fn update_account_lock_settings(&self, account_id: &str) -> Result<()> {
+    pub async fn update_lock_settings(&self, account_id: &str) -> Result<()> {
         let url = format!(
             "/accounts/{}/lock_settings",
             crate::progenitor_support::encode_path(&account_id.to_string()),
@@ -689,21 +659,14 @@ impl Accounts {
      *
      * * `account_id: &str` -- The account's account ID.
      */
-    pub async fn update_account_owner(
-        &self,
-        account_id: &str,
-        body: &crate::types::Members,
-    ) -> Result<()> {
+    pub async fn update_owner(&self, account_id: &str, body: &crate::types::Members) -> Result<()> {
         let url = format!(
             "/accounts/{}/owner",
             crate::progenitor_support::encode_path(&account_id.to_string()),
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -737,10 +700,7 @@ impl Accounts {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -763,21 +723,15 @@ impl Accounts {
      * * `file_ids: &str` -- Provide the id of the file that is to be deleted. To delete multiple files, provide comma separated values for this field.
      */
     pub async fn del_vb(&self, account_id: &str, file_ids: &str) -> Result<()> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !file_ids.is_empty() {
-            query_args.push(format!("file_ids={}", file_ids));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("file_ids".to_string(), file_ids.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/accounts/{}/settings/virtual_backgrounds?{}",
             crate::progenitor_support::encode_path(&account_id.to_string()),
-            query
+            query_
         );
 
         self.client.delete(&url, None).await
