@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct ChatMessages {
-    client: Client,
+    pub client: Client,
 }
 
 impl ChatMessages {
@@ -52,41 +52,36 @@ impl ChatMessages {
         next_page_token: &str,
         include_deleted_and_edited_message: &str,
     ) -> Result<Vec<crate::types::Messages>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("date={}", date));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !date.to_string().is_empty() {
+            query_args.push(("date".to_string(), date.to_string()));
+        }
         if !include_deleted_and_edited_message.is_empty() {
-            query_args.push(format!(
-                "include_deleted_and_edited_message={}",
-                include_deleted_and_edited_message
+            query_args.push((
+                "include_deleted_and_edited_message".to_string(),
+                include_deleted_and_edited_message.to_string(),
             ));
         }
         if !next_page_token.is_empty() {
-            query_args.push(format!("next_page_token={}", next_page_token));
+            query_args.push(("next_page_token".to_string(), next_page_token.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
+            query_args.push(("page_size".to_string(), page_size.to_string()));
         }
         if !to_channel.is_empty() {
-            query_args.push(format!("to_channel={}", to_channel));
+            query_args.push(("to_channel".to_string(), to_channel.to_string()));
         }
         if !to_contact.is_empty() {
-            query_args.push(format!("to_contact={}", to_contact));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("to_contact".to_string(), to_contact.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/chat/users/{}/messages?{}",
             crate::progenitor_support::encode_path(&user_id.to_string()),
-            query
+            query_
         );
 
-        let resp: crate::types::GetChatMessagesResponse =
-            self.client.get(&url, None).await.unwrap();
+        let resp: crate::types::GetChatMessagesResponse = self.client.get(&url, None).await?;
 
         // Return our response data.
         Ok(resp.messages)
@@ -118,35 +113,30 @@ impl ChatMessages {
         date: chrono::NaiveDate,
         include_deleted_and_edited_message: &str,
     ) -> Result<Vec<crate::types::Messages>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("date={}", date));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !date.to_string().is_empty() {
+            query_args.push(("date".to_string(), date.to_string()));
+        }
         if !include_deleted_and_edited_message.is_empty() {
-            query_args.push(format!(
-                "include_deleted_and_edited_message={}",
-                include_deleted_and_edited_message
+            query_args.push((
+                "include_deleted_and_edited_message".to_string(),
+                include_deleted_and_edited_message.to_string(),
             ));
         }
         if !to_channel.is_empty() {
-            query_args.push(format!("to_channel={}", to_channel));
+            query_args.push(("to_channel".to_string(), to_channel.to_string()));
         }
         if !to_contact.is_empty() {
-            query_args.push(format!("to_contact={}", to_contact));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("to_contact".to_string(), to_contact.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/chat/users/{}/messages?{}",
             crate::progenitor_support::encode_path(&user_id.to_string()),
-            query
+            query_
         );
 
-        let mut resp: crate::types::GetChatMessagesResponse =
-            self.client.get(&url, None).await.unwrap();
+        let mut resp: crate::types::GetChatMessagesResponse = self.client.get(&url, None).await?;
 
         let mut messages = resp.messages;
         let mut page = resp.next_page_token;
@@ -158,14 +148,12 @@ impl ChatMessages {
                 resp = self
                     .client
                     .get(&format!("{}?next_page_token={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             } else {
                 resp = self
                     .client
                     .get(&format!("{}&next_page_token={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             }
 
             messages.append(&mut resp.messages);
@@ -194,7 +182,7 @@ impl ChatMessages {
      *
      *  <p style="background-color:#e1f5fe; color:#01579b; padding:8px"> <b>Note:</b> For an <b>account-level</b> <a href="https://marketplace.zoom.us/docs/guides/getting-started/app-types/create-oauth-app">OAuth app</a>, this API can only be used on behalf of a user who is assigned with a <a href="https://support.zoom.us/hc/en-us/articles/115001078646-Using-role-management#:~:text=Each%20user%20in%20a%20Zoom,owner%2C%20administrator%2C%20or%20member.&text=Role%2Dbased%20access%20control%20enables,needs%20to%20view%20or%20edit."> role</a> that has the <b>Edit</b> permission for <b>Chat Messages</b>.</p>
      */
-    pub async fn senda_chat_message(
+    pub async fn senda(
         &self,
         user_id: &str,
         body: &crate::types::SendaChatMessageRequest,
@@ -205,10 +193,7 @@ impl ChatMessages {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -241,10 +226,7 @@ impl ChatMessages {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -277,10 +259,7 @@ impl ChatMessages {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -305,32 +284,26 @@ impl ChatMessages {
      * * `to_contact: &str` -- The `userId` or email address of a Zoom Chat contact to whom you sent the message.\n\n**Note:** You must use this query parameter to delete a message sent to a Zoom Chat contact. .
      * * `to_channel: &str` -- The `channelId` of the Zoom Chat channel where sent the message.\n\n**Note:** You must use this query parameter to delete a message sent to Zoom Chat channel.
      */
-    pub async fn get_chat_message(
+    pub async fn get(
         &self,
         user_id: &str,
         message_id: &str,
         to_contact: &str,
         to_channel: &str,
     ) -> Result<crate::types::GetChatMessageResponse> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !to_channel.is_empty() {
-            query_args.push(format!("to_channel={}", to_channel));
+            query_args.push(("to_channel".to_string(), to_channel.to_string()));
         }
         if !to_contact.is_empty() {
-            query_args.push(format!("to_contact={}", to_contact));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("to_contact".to_string(), to_contact.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/chat/users/{}/messages/{}?{}",
             crate::progenitor_support::encode_path(&user_id.to_string()),
             crate::progenitor_support::encode_path(&message_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -367,10 +340,7 @@ impl ChatMessages {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -402,32 +372,26 @@ impl ChatMessages {
      *   
      *   You must provide either `to_contact` or `to_channel` as a query parameter to delete a message that was previously sent to either an individual or a chat channel .
      */
-    pub async fn delete_chat_message(
+    pub async fn delete(
         &self,
         user_id: &str,
         message_id: &str,
         to_contact: &str,
         to_channel: &str,
     ) -> Result<()> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !to_channel.is_empty() {
-            query_args.push(format!("to_channel={}", to_channel));
+            query_args.push(("to_channel".to_string(), to_channel.to_string()));
         }
         if !to_contact.is_empty() {
-            query_args.push(format!("to_contact={}", to_contact));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("to_contact".to_string(), to_contact.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/chat/users/{}/messages/{}?{}",
             crate::progenitor_support::encode_path(&user_id.to_string()),
             crate::progenitor_support::encode_path(&message_id.to_string()),
-            query
+            query_
         );
 
         self.client.delete(&url, None).await
