@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct CloudRecording {
-    client: Client,
+    pub client: Client,
 }
 
 impl CloudRecording {
@@ -55,35 +55,33 @@ impl CloudRecording {
         to: chrono::NaiveDate,
         trash_type: &str,
     ) -> Result<crate::types::Domains> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("from={}", from));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !from.to_string().is_empty() {
+            query_args.push(("from".to_string(), from.to_string()));
+        }
         if !mc.is_empty() {
-            query_args.push(format!("mc={}", mc));
+            query_args.push(("mc".to_string(), mc.to_string()));
         }
         if !next_page_token.is_empty() {
-            query_args.push(format!("next_page_token={}", next_page_token));
+            query_args.push(("next_page_token".to_string(), next_page_token.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
+            query_args.push(("page_size".to_string(), page_size.to_string()));
+        }
+        if !to.to_string().is_empty() {
+            query_args.push(("to".to_string(), to.to_string()));
         }
-        query_args.push(format!("to={}", to));
         if trash {
-            query_args.push(format!("trash={}", trash));
+            query_args.push(("trash".to_string(), trash.to_string()));
         }
         if !trash_type.is_empty() {
-            query_args.push(format!("trash_type={}", trash_type));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("trash_type".to_string(), trash_type.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/users/{}/recordings?{}",
             crate::progenitor_support::encode_path(&user_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -116,22 +114,18 @@ impl CloudRecording {
         include_fields: &str,
         ttl: u64,
     ) -> Result<crate::types::RecordingGetResponseAllOf> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !include_fields.is_empty() {
-            query_args.push(format!("include_fields={}", include_fields));
+            query_args.push(("include_fields".to_string(), include_fields.to_string()));
         }
-        query_args.push(format!("ttl={}", ttl));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !ttl.to_string().is_empty() {
+            query_args.push(("ttl".to_string(), ttl.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/meetings/{}/recordings?{}",
             crate::progenitor_support::encode_path(&meeting_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -164,19 +158,15 @@ impl CloudRecording {
         meeting_id: &str,
         action: crate::types::RecordingDeleteAction,
     ) -> Result<()> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("action={}", action));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !action.to_string().is_empty() {
+            query_args.push(("action".to_string(), action.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/meetings/{}/recordings?{}",
             crate::progenitor_support::encode_path(&meeting_id.to_string()),
-            query
+            query_
         );
 
         self.client.delete(&url, None).await
@@ -207,20 +197,16 @@ impl CloudRecording {
         recording_id: &str,
         action: crate::types::RecordingDeleteAction,
     ) -> Result<()> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("action={}", action));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !action.to_string().is_empty() {
+            query_args.push(("action".to_string(), action.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/meetings/{}/recordings/{}?{}",
             crate::progenitor_support::encode_path(&meeting_id.to_string()),
             crate::progenitor_support::encode_path(&recording_id.to_string()),
-            query
+            query_
         );
 
         self.client.delete(&url, None).await
@@ -257,10 +243,7 @@ impl CloudRecording {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -297,10 +280,7 @@ impl CloudRecording {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -363,10 +343,7 @@ impl CloudRecording {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -404,28 +381,24 @@ impl CloudRecording {
         page_number: i64,
         next_page_token: &str,
     ) -> Result<crate::types::Domains> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !next_page_token.is_empty() {
-            query_args.push(format!("next_page_token={}", next_page_token));
+            query_args.push(("next_page_token".to_string(), next_page_token.to_string()));
         }
         if page_number > 0 {
-            query_args.push(format!("page_number={}", page_number));
+            query_args.push(("page_number".to_string(), page_number.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
+            query_args.push(("page_size".to_string(), page_size.to_string()));
         }
-        query_args.push(format!("status={}", status));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !status.to_string().is_empty() {
+            query_args.push(("status".to_string(), status.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/meetings/{}/recordings/registrants?{}",
             crate::progenitor_support::encode_path(&meeting_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -493,10 +466,7 @@ impl CloudRecording {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -564,10 +534,7 @@ impl CloudRecording {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -605,34 +572,28 @@ impl CloudRecording {
         from: Option<chrono::DateTime<chrono::Utc>>,
         to: Option<chrono::DateTime<chrono::Utc>>,
     ) -> Result<Vec<crate::types::GetAccountCloudRecordingResponseMeetings>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if let Some(date) = from {
-            query_args.push(format!("from={}", &date.to_rfc3339()));
+            query_args.push(("from".to_string(), date.to_rfc3339()));
         }
         if !next_page_token.is_empty() {
-            query_args.push(format!("next_page_token={}", next_page_token));
+            query_args.push(("next_page_token".to_string(), next_page_token.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
+            query_args.push(("page_size".to_string(), page_size.to_string()));
         }
         if let Some(date) = to {
-            query_args.push(format!("to={}", &date.to_rfc3339()));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("to".to_string(), date.to_rfc3339()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/accounts/{}/recordings?{}",
             crate::progenitor_support::encode_path(&account_id.to_string()),
-            query
+            query_
         );
 
         let resp: crate::types::GetAccountCloudRecordingResponse =
-            self.client.get(&url, None).await.unwrap();
+            self.client.get(&url, None).await?;
 
         // Return our response data.
         Ok(resp.meetings)
@@ -664,28 +625,22 @@ impl CloudRecording {
         from: Option<chrono::DateTime<chrono::Utc>>,
         to: Option<chrono::DateTime<chrono::Utc>>,
     ) -> Result<Vec<crate::types::GetAccountCloudRecordingResponseMeetings>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if let Some(date) = from {
-            query_args.push(format!("from={}", &date.to_rfc3339()));
+            query_args.push(("from".to_string(), date.to_rfc3339()));
         }
         if let Some(date) = to {
-            query_args.push(format!("to={}", &date.to_rfc3339()));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("to".to_string(), date.to_rfc3339()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/accounts/{}/recordings?{}",
             crate::progenitor_support::encode_path(&account_id.to_string()),
-            query
+            query_
         );
 
         let mut resp: crate::types::GetAccountCloudRecordingResponse =
-            self.client.get(&url, None).await.unwrap();
+            self.client.get(&url, None).await?;
 
         let mut meetings = resp.meetings;
         let mut page = resp.next_page_token;
@@ -697,14 +652,12 @@ impl CloudRecording {
                 resp = self
                     .client
                     .get(&format!("{}?next_page_token={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             } else {
                 resp = self
                     .client
                     .get(&format!("{}&next_page_token={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             }
 
             meetings.append(&mut resp.meetings);
