@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct Groups {
-    client: Client,
+    pub client: Client,
 }
 
 impl Groups {
@@ -43,13 +43,10 @@ impl Groups {
      *  
      *  **[Rate Limit Label](https://marketplace.zoom.us/docs/api-reference/rate-limits#rate-limits):** `Light`
      */
-    pub async fn group_create(&self, body: &crate::types::GroupCreateRequest) -> Result<()> {
+    pub async fn create(&self, body: &crate::types::GroupCreateRequest) -> Result<()> {
         let url = "/groups".to_string();
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -96,7 +93,7 @@ impl Groups {
      * * `group_id: &str` -- The group ID.<br>
      *   Can be retrieved by calling [GET /groups](https://marketplace.zoom.us/docs/api-reference/zoom-api/groups/groups).
      */
-    pub async fn group_delete(&self, group_id: &str) -> Result<()> {
+    pub async fn delete(&self, group_id: &str) -> Result<()> {
         let url = format!(
             "/groups/{}",
             crate::progenitor_support::encode_path(&group_id.to_string()),
@@ -122,7 +119,7 @@ impl Groups {
      * * `group_id: &str` -- The group ID.<br>
      *   Can be retrieved by calling [GET /groups](https://marketplace.zoom.us/docs/api-reference/zoom-api/groups/groups).
      */
-    pub async fn group_update(
+    pub async fn update(
         &self,
         group_id: &str,
         body: &crate::types::GroupCreateRequest,
@@ -133,10 +130,7 @@ impl Groups {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -163,38 +157,31 @@ impl Groups {
      *   The page number of the current page in the returned records.
      * * `next_page_token: &str` -- The next page token is used to paginate through large result sets. A next page token will be returned whenever the set of available results exceeds the current page size. The expiration period for this token is 15 minutes.
      */
-    pub async fn group_members(
+    pub async fn members(
         &self,
         group_id: &str,
         page_size: i64,
         page_number: i64,
         next_page_token: &str,
     ) -> Result<Vec<crate::types::UserCreateResponse>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !next_page_token.is_empty() {
-            query_args.push(format!("next_page_token={}", next_page_token));
+            query_args.push(("next_page_token".to_string(), next_page_token.to_string()));
         }
         if page_number > 0 {
-            query_args.push(format!("page_number={}", page_number));
+            query_args.push(("page_number".to_string(), page_number.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("page_size".to_string(), page_size.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/groups/{}/members?{}",
             crate::progenitor_support::encode_path(&group_id.to_string()),
-            query
+            query_
         );
 
-        let resp: crate::types::GroupMembersResponseData =
-            self.client.get(&url, None).await.unwrap();
+        let resp: crate::types::GroupMembersResponseData = self.client.get(&url, None).await?;
 
         // Return our response data.
         Ok(resp.members)
@@ -205,7 +192,7 @@ impl Groups {
      *
      * This function performs a `GET` to the `/groups/{groupId}/members` endpoint.
      *
-     * As opposed to `group_members`, this function returns all the pages of the request at once.
+     * As opposed to `members`, this function returns all the pages of the request at once.
      *
      * List the members of a [group](https://support.zoom.us/hc/en-us/articles/204519819-Group-Management-) under your account.
      *
@@ -214,7 +201,7 @@ impl Groups {
      *
      *  **[Rate Limit Label](https://marketplace.zoom.us/docs/api-reference/rate-limits#rate-limits):** `Medium`
      */
-    pub async fn get_all_group_members(
+    pub async fn get_all_members(
         &self,
         group_id: &str,
     ) -> Result<Vec<crate::types::UserCreateResponse>> {
@@ -223,8 +210,7 @@ impl Groups {
             crate::progenitor_support::encode_path(&group_id.to_string()),
         );
 
-        let mut resp: crate::types::GroupMembersResponseData =
-            self.client.get(&url, None).await.unwrap();
+        let mut resp: crate::types::GroupMembersResponseData = self.client.get(&url, None).await?;
 
         let mut members = resp.members;
         let mut page = resp.next_page_token;
@@ -236,14 +222,12 @@ impl Groups {
                 resp = self
                     .client
                     .get(&format!("{}?next_page_token={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             } else {
                 resp = self
                     .client
                     .get(&format!("{}&next_page_token={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             }
 
             members.append(&mut resp.members);
@@ -276,7 +260,7 @@ impl Groups {
      * * `group_id: &str` -- The group ID.<br>
      *   Can be retrieved by calling [GET /groups](https://marketplace.zoom.us/docs/api-reference/zoom-api/groups/groups).
      */
-    pub async fn group_members_create(
+    pub async fn members_create(
         &self,
         group_id: &str,
         body: &crate::types::AddRoleMembersRequest,
@@ -287,10 +271,7 @@ impl Groups {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -312,7 +293,7 @@ impl Groups {
      *   Can be retrieved by calling [GET /groups](https://marketplace.zoom.us/docs/api-reference/zoom-api/groups/groups).
      * * `member_id: &str` -- User's first name.
      */
-    pub async fn group_members_delete(&self, group_id: &str, member_id: &str) -> Result<()> {
+    pub async fn members_delete(&self, group_id: &str, member_id: &str) -> Result<()> {
         let url = format!(
             "/groups/{}/members/{}",
             crate::progenitor_support::encode_path(&group_id.to_string()),
@@ -345,7 +326,7 @@ impl Groups {
      *   * To move a group member from one group to another, use the `groupId` of the designated group.
      * * `member_id: &str` -- The group member's unique ID. To get this value, use the [List Group Members](https://marketplace.zoom.us/docs/api-reference/zoom-api/groups/groupmembers) API.
      */
-    pub async fn update_a_group_member(
+    pub async fn update_member(
         &self,
         group_id: &str,
         member_id: &str,
@@ -358,10 +339,7 @@ impl Groups {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -384,28 +362,27 @@ impl Groups {
      *  \* `security` — View the account's security settings. For example, password requirements for user login or two-factor authentication.<br>
      *  \* `meeting_security` — View the account's meeting security settings.
      */
-    pub async fn get_group_settings_domains(
+    pub async fn get_settings_domains(
         &self,
         group_id: &str,
         custom_query_fields: &str,
         option: crate::types::OptionData,
     ) -> Result<crate::types::Domains> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !custom_query_fields.is_empty() {
-            query_args.push(format!("custom_query_fields={}", custom_query_fields));
+            query_args.push((
+                "custom_query_fields".to_string(),
+                custom_query_fields.to_string(),
+            ));
         }
-        query_args.push(format!("option={}", option));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !option.to_string().is_empty() {
+            query_args.push(("option".to_string(), option.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/groups/{}/settings?{}",
             crate::progenitor_support::encode_path(&group_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -430,28 +407,27 @@ impl Groups {
      *  \* `security` — View the account's security settings. For example, password requirements for user login or two-factor authentication.<br>
      *  \* `meeting_security` — View the account's meeting security settings.
      */
-    pub async fn get_group_settings_meeting_security(
+    pub async fn get_settings_meeting_security(
         &self,
         group_id: &str,
         custom_query_fields: &str,
         option: crate::types::OptionData,
     ) -> Result<crate::types::MeetingSecuritySettings> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !custom_query_fields.is_empty() {
-            query_args.push(format!("custom_query_fields={}", custom_query_fields));
+            query_args.push((
+                "custom_query_fields".to_string(),
+                custom_query_fields.to_string(),
+            ));
         }
-        query_args.push(format!("option={}", option));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !option.to_string().is_empty() {
+            query_args.push(("option".to_string(), option.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/groups/{}/settings?{}",
             crate::progenitor_support::encode_path(&group_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -476,28 +452,27 @@ impl Groups {
      *  \* `security` — View the account's security settings. For example, password requirements for user login or two-factor authentication.<br>
      *  \* `meeting_security` — View the account's meeting security settings.
      */
-    pub async fn get_group_settings_response(
+    pub async fn get_settings_group_response(
         &self,
         group_id: &str,
         custom_query_fields: &str,
         option: crate::types::OptionData,
     ) -> Result<crate::types::GetGroupSettingsResponse> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !custom_query_fields.is_empty() {
-            query_args.push(format!("custom_query_fields={}", custom_query_fields));
+            query_args.push((
+                "custom_query_fields".to_string(),
+                custom_query_fields.to_string(),
+            ));
         }
-        query_args.push(format!("option={}", option));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !option.to_string().is_empty() {
+            query_args.push(("option".to_string(), option.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/groups/{}/settings?{}",
             crate::progenitor_support::encode_path(&group_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -522,28 +497,27 @@ impl Groups {
      *  \* `security` — View the account's security settings. For example, password requirements for user login or two-factor authentication.<br>
      *  \* `meeting_security` — View the account's meeting security settings.
      */
-    pub async fn get_group_setting(
+    pub async fn get_setting(
         &self,
         group_id: &str,
         custom_query_fields: &str,
         option: crate::types::OptionData,
     ) -> Result<crate::types::GetGroupSettingsResponseOneOf> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !custom_query_fields.is_empty() {
-            query_args.push(format!("custom_query_fields={}", custom_query_fields));
+            query_args.push((
+                "custom_query_fields".to_string(),
+                custom_query_fields.to_string(),
+            ));
         }
-        query_args.push(format!("option={}", option));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !option.to_string().is_empty() {
+            query_args.push(("option".to_string(), option.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/groups/{}/settings?{}",
             crate::progenitor_support::encode_path(&group_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -565,36 +539,32 @@ impl Groups {
      * * `group_id: &str` -- User's first name.
      * * `option: crate::types::UpdateGroupSettingsOption`
      */
-    pub async fn update_group_settings(
+    pub async fn update_settings(
         &self,
         group_id: &str,
         custom_query_fields: &str,
         option: crate::types::UpdateGroupSettingsOption,
         body: &crate::types::UpdateGroupSettingsRequestOneOf,
     ) -> Result<()> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !custom_query_fields.is_empty() {
-            query_args.push(format!("custom_query_fields={}", custom_query_fields));
+            query_args.push((
+                "custom_query_fields".to_string(),
+                custom_query_fields.to_string(),
+            ));
         }
-        query_args.push(format!("option={}", option));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !option.to_string().is_empty() {
+            query_args.push(("option".to_string(), option.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/groups/{}/settings?{}",
             crate::progenitor_support::encode_path(&group_id.to_string()),
-            query
+            query_
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -615,30 +585,27 @@ impl Groups {
      * * `group_id: &str` -- User's first name.
      * * `option: &str` -- Specify `meeting_security` as the value of this field if you would like to view security settings applied on a meeting hosted by the users in this group.
      */
-    pub async fn get_group_lock_settings_meeting_security(
+    pub async fn get_lock_settings_meeting_security(
         &self,
         group_id: &str,
         custom_query_fields: &str,
         option: &str,
     ) -> Result<crate::types::MeetingSecuritySettings> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !custom_query_fields.is_empty() {
-            query_args.push(format!("custom_query_fields={}", custom_query_fields));
+            query_args.push((
+                "custom_query_fields".to_string(),
+                custom_query_fields.to_string(),
+            ));
         }
         if !option.is_empty() {
-            query_args.push(format!("option={}", option));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("option".to_string(), option.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/groups/{}/lock_settings?{}",
             crate::progenitor_support::encode_path(&group_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -661,30 +628,27 @@ impl Groups {
      * * `group_id: &str` -- User's first name.
      * * `option: &str` -- Specify `meeting_security` as the value of this field if you would like to view security settings applied on a meeting hosted by the users in this group.
      */
-    pub async fn get_group_lock_settings_response(
+    pub async fn get_lock_settings_group_response(
         &self,
         group_id: &str,
         custom_query_fields: &str,
         option: &str,
     ) -> Result<crate::types::GetGroupLockSettingsResponse> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !custom_query_fields.is_empty() {
-            query_args.push(format!("custom_query_fields={}", custom_query_fields));
+            query_args.push((
+                "custom_query_fields".to_string(),
+                custom_query_fields.to_string(),
+            ));
         }
         if !option.is_empty() {
-            query_args.push(format!("option={}", option));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("option".to_string(), option.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/groups/{}/lock_settings?{}",
             crate::progenitor_support::encode_path(&group_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -707,30 +671,27 @@ impl Groups {
      * * `group_id: &str` -- User's first name.
      * * `option: &str` -- Specify `meeting_security` as the value of this field if you would like to view security settings applied on a meeting hosted by the users in this group.
      */
-    pub async fn get_group_lock_setting(
+    pub async fn get_lock_setting(
         &self,
         group_id: &str,
         custom_query_fields: &str,
         option: &str,
     ) -> Result<crate::types::GetGroupLockSettingsResponseOneOf> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !custom_query_fields.is_empty() {
-            query_args.push(format!("custom_query_fields={}", custom_query_fields));
+            query_args.push((
+                "custom_query_fields".to_string(),
+                custom_query_fields.to_string(),
+            ));
         }
         if !option.is_empty() {
-            query_args.push(format!("option={}", option));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("option".to_string(), option.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/groups/{}/lock_settings?{}",
             crate::progenitor_support::encode_path(&group_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -753,38 +714,32 @@ impl Groups {
      * * `group_id: &str` -- User's first name.
      * * `option: &str` -- Specify `meeting_security` as the value of this field if you would like to view security settings applied on a meeting hosted by the users in this group.
      */
-    pub async fn group_locked_settings(
+    pub async fn locked_settings(
         &self,
         group_id: &str,
         custom_query_fields: &str,
         option: &str,
         body: &crate::types::GroupLockedSettingsRequestOneOf,
     ) -> Result<()> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !custom_query_fields.is_empty() {
-            query_args.push(format!("custom_query_fields={}", custom_query_fields));
+            query_args.push((
+                "custom_query_fields".to_string(),
+                custom_query_fields.to_string(),
+            ));
         }
         if !option.is_empty() {
-            query_args.push(format!("option={}", option));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("option".to_string(), option.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/groups/{}/lock_settings?{}",
             crate::progenitor_support::encode_path(&group_id.to_string()),
-            query
+            query_
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -808,34 +763,25 @@ impl Groups {
      *
      * * `group_id: &str` -- Unique identifier of the group. Retrieve the value for this field by calling the [List groups](https://marketplace.zoom.us/docs/api-reference/zoom-api/groups/groups) API.
      */
-    pub async fn upload_group_vb(
+    pub async fn upload_vb(
         &self,
         file_ids: &str,
         group_id: &str,
         body: &crate::types::UploadVbRequest,
     ) -> Result<crate::types::Files> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !file_ids.is_empty() {
-            query_args.push(format!("file_ids={}", file_ids));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("file_ids".to_string(), file_ids.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/groups/{}/settings/virtual_backgrounds?{}",
             crate::progenitor_support::encode_path(&group_id.to_string()),
-            query
+            query_
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -858,22 +804,16 @@ impl Groups {
      * * `group_id: &str` -- Unique identifier of the group. Retrieve the value for this field by calling the [List groups](https://marketplace.zoom.us/docs/api-reference/zoom-api/groups/groups) API.
      * * `file_ids: &str` -- Provide the id of the file that is to be deleted. To delete multiple files, provide comma separated values for this field.
      */
-    pub async fn del_group_vb(&self, file_ids: &str, group_id: &str) -> Result<()> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+    pub async fn del_vb(&self, file_ids: &str, group_id: &str) -> Result<()> {
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !file_ids.is_empty() {
-            query_args.push(format!("file_ids={}", file_ids));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("file_ids".to_string(), file_ids.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/groups/{}/settings/virtual_backgrounds?{}",
             crate::progenitor_support::encode_path(&group_id.to_string()),
-            query
+            query_
         );
 
         self.client.delete(&url, None).await
