@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct Meetings {
-    client: Client,
+    pub client: Client,
 }
 
 impl Meetings {
@@ -39,28 +39,24 @@ impl Meetings {
         next_page_token: &str,
         page_number: &str,
     ) -> Result<crate::types::Domains> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !next_page_token.is_empty() {
-            query_args.push(format!("next_page_token={}", next_page_token));
+            query_args.push(("next_page_token".to_string(), next_page_token.to_string()));
         }
         if !page_number.is_empty() {
-            query_args.push(format!("page_number={}", page_number));
+            query_args.push(("page_number".to_string(), page_number.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
+            query_args.push(("page_size".to_string(), page_size.to_string()));
         }
-        query_args.push(format!("type={}", type_));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !type_.to_string().is_empty() {
+            query_args.push(("type".to_string(), type_.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/users/{}/meetings?{}",
             crate::progenitor_support::encode_path(&user_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -88,7 +84,7 @@ impl Meetings {
      *
      * * `user_id: &str` -- The user ID or email address of the user. For user-level apps, pass `me` as the value for userId.
      */
-    pub async fn meeting_create(
+    pub async fn create(
         &self,
         user_id: &str,
         body: &crate::types::MeetingCreate,
@@ -99,10 +95,7 @@ impl Meetings {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -132,27 +125,21 @@ impl Meetings {
         occurrence_id: &str,
         show_previous_occurrences: bool,
     ) -> Result<crate::types::MeetingResponseAllOf> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !occurrence_id.is_empty() {
-            query_args.push(format!("occurrence_id={}", occurrence_id));
+            query_args.push(("occurrence_id".to_string(), occurrence_id.to_string()));
         }
         if show_previous_occurrences {
-            query_args.push(format!(
-                "show_previous_occurrences={}",
-                show_previous_occurrences
+            query_args.push((
+                "show_previous_occurrences".to_string(),
+                show_previous_occurrences.to_string(),
             ));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/meetings/{}?{}",
             crate::progenitor_support::encode_path(&meeting_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -183,37 +170,34 @@ impl Meetings {
      *   
      *   The default value of this field is `false`.
      */
-    pub async fn meeting_delete(
+    pub async fn delete(
         &self,
         meeting_id: i64,
         occurrence_id: &str,
         schedule_for_reminder: bool,
         cancel_meeting_reminder: &str,
     ) -> Result<()> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !cancel_meeting_reminder.is_empty() {
-            query_args.push(format!(
-                "cancel_meeting_reminder={}",
-                cancel_meeting_reminder
+            query_args.push((
+                "cancel_meeting_reminder".to_string(),
+                cancel_meeting_reminder.to_string(),
             ));
         }
         if !occurrence_id.is_empty() {
-            query_args.push(format!("occurrence_id={}", occurrence_id));
+            query_args.push(("occurrence_id".to_string(), occurrence_id.to_string()));
         }
         if schedule_for_reminder {
-            query_args.push(format!("schedule_for_reminder={}", schedule_for_reminder));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push((
+                "schedule_for_reminder".to_string(),
+                schedule_for_reminder.to_string(),
+            ));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/meetings/{}?{}",
             crate::progenitor_support::encode_path(&meeting_id.to_string()),
-            query
+            query_
         );
 
         self.client.delete(&url, None).await
@@ -235,34 +219,25 @@ impl Meetings {
      *   While storing it in your database, store it as a **long** data type and **not as an integer**, as the Meeting IDs can be longer than 10 digits.
      * * `occurrence_id: &str` -- Meeting occurrence id. Support change of agenda, start_time, duration, settings: {host_video, participant_video, join_before_host, mute_upon_entry, waiting_room, watermark, auto_recording}.
      */
-    pub async fn meeting_update(
+    pub async fn update(
         &self,
         meeting_id: i64,
         occurrence_id: &str,
         body: &crate::types::MeetingUpdateRequestAllOf,
     ) -> Result<()> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !occurrence_id.is_empty() {
-            query_args.push(format!("occurrence_id={}", occurrence_id));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("occurrence_id".to_string(), occurrence_id.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/meetings/{}?{}",
             crate::progenitor_support::encode_path(&meeting_id.to_string()),
-            query
+            query_
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -281,7 +256,7 @@ impl Meetings {
      *   
      *   While storing it in your database, store it as a **long** data type and **not as an integer**, as the Meeting IDs can be longer than 10 digits.
      */
-    pub async fn meeting_status(
+    pub async fn status(
         &self,
         meeting_id: i64,
         body: &crate::types::MeetingStatusRequest,
@@ -292,10 +267,7 @@ impl Meetings {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -323,7 +295,7 @@ impl Meetings {
      *   The page number of the current page in the returned records.
      * * `next_page_token: &str` -- The next page token is used to paginate through large result sets. A next page token will be returned whenever the set of available results exceeds the current page size. The expiration period for this token is 15 minutes.
      */
-    pub async fn meeting_registrant(
+    pub async fn registrant(
         &self,
         meeting_id: i64,
         occurrence_id: &str,
@@ -332,31 +304,27 @@ impl Meetings {
         page_number: i64,
         next_page_token: &str,
     ) -> Result<crate::types::Domains> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !next_page_token.is_empty() {
-            query_args.push(format!("next_page_token={}", next_page_token));
+            query_args.push(("next_page_token".to_string(), next_page_token.to_string()));
         }
         if !occurrence_id.is_empty() {
-            query_args.push(format!("occurrence_id={}", occurrence_id));
+            query_args.push(("occurrence_id".to_string(), occurrence_id.to_string()));
         }
         if page_number > 0 {
-            query_args.push(format!("page_number={}", page_number));
+            query_args.push(("page_number".to_string(), page_number.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
+            query_args.push(("page_size".to_string(), page_size.to_string()));
         }
-        query_args.push(format!("status={}", status));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !status.to_string().is_empty() {
+            query_args.push(("status".to_string(), status.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/meetings/{}/registrants?{}",
             crate::progenitor_support::encode_path(&meeting_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -382,26 +350,20 @@ impl Meetings {
      *   While storing it in your database, store it as a **long** data type and **not as an integer**, as the Meeting IDs can be longer than 10 digits.
      * * `occurrence_ids: &str` -- Occurrence IDs. You can find these with the meeting get API. Multiple values separated by comma.
      */
-    pub async fn meeting_registrant_create(
+    pub async fn registrant_create(
         &self,
         meeting_id: i64,
         occurrence_ids: &str,
     ) -> Result<crate::types::MeetingRegistrantCreateResponse> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !occurrence_ids.is_empty() {
-            query_args.push(format!("occurrence_ids={}", occurrence_ids));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("occurrence_ids".to_string(), occurrence_ids.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/meetings/{}/registrants?{}",
             crate::progenitor_support::encode_path(&meeting_id.to_string()),
-            query
+            query_
         );
 
         self.client.post(&url, None).await
@@ -429,22 +391,16 @@ impl Meetings {
         meeting_id: i64,
         registrant_id: &str,
     ) -> Result<()> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !occurrence_id.is_empty() {
-            query_args.push(format!("occurrence_id={}", occurrence_id));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("occurrence_id".to_string(), occurrence_id.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/meetings/{}/registrants/{}?{}",
             crate::progenitor_support::encode_path(&meeting_id.to_string()),
             crate::progenitor_support::encode_path(&registrant_id.to_string()),
-            query
+            query_
         );
 
         self.client.delete(&url, None).await
@@ -466,34 +422,25 @@ impl Meetings {
      *   While storing it in your database, store it as a **long** data type and **not as an integer**, as the Meeting IDs can be longer than 10 digits.
      * * `occurrence_id: &str` -- The meeting occurrence ID.
      */
-    pub async fn meeting_registrant_status(
+    pub async fn registrant_status(
         &self,
         meeting_id: i64,
         occurrence_id: &str,
         body: &crate::types::RegistrantStatus,
     ) -> Result<()> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !occurrence_id.is_empty() {
-            query_args.push(format!("occurrence_id={}", occurrence_id));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("occurrence_id".to_string(), occurrence_id.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/meetings/{}/registrants/status?{}",
             crate::progenitor_support::encode_path(&meeting_id.to_string()),
-            query
+            query_
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -514,7 +461,7 @@ impl Meetings {
      *   
      *   If the meeting UUID begins with a `/` character or contains a `//` character, you **must** double-encode the meeting UUID when using the meeting UUID for other API calls.
      */
-    pub async fn past_meeting_details(
+    pub async fn past_details(
         &self,
         meeting_uuid: &str,
     ) -> Result<crate::types::PastMeetingDetailsResponse> {
@@ -549,30 +496,24 @@ impl Meetings {
      * * `page_size: i64` -- The number of records returned within a single API call.
      * * `next_page_token: &str` -- The next page token is used to paginate through large result sets. A next page token will be returned whenever the set of available results exceeds the current page size. The expiration period for this token is 15 minutes.
      */
-    pub async fn past_meeting_participant(
+    pub async fn past_participant(
         &self,
         meeting_uuid: &str,
         page_size: i64,
         next_page_token: &str,
     ) -> Result<crate::types::PastMeetingParticipantsResponseAllOf> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !next_page_token.is_empty() {
-            query_args.push(format!("next_page_token={}", next_page_token));
+            query_args.push(("next_page_token".to_string(), next_page_token.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("page_size".to_string(), page_size.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/past_meetings/{}/participants?{}",
             crate::progenitor_support::encode_path(&meeting_uuid.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -622,7 +563,7 @@ impl Meetings {
      *   
      *   While storing it in your database, store it as a **long** data type and **not as an integer**, as the Meeting IDs can be longer than 10 digits.
      */
-    pub async fn meeting_poll(&self, meeting_id: i64) -> Result<crate::types::Domains> {
+    pub async fn poll(&self, meeting_id: i64) -> Result<crate::types::Domains> {
         let url = format!(
             "/meetings/{}/polls",
             crate::progenitor_support::encode_path(&meeting_id.to_string()),
@@ -651,7 +592,7 @@ impl Meetings {
      *   
      *   While storing it in your database, store it as a **long** data type and **not as an integer**, as the Meeting IDs can be longer than 10 digits.
      */
-    pub async fn meeting_poll_create(
+    pub async fn poll_create(
         &self,
         meeting_id: i64,
         body: &crate::types::Poll,
@@ -662,10 +603,7 @@ impl Meetings {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -689,7 +627,7 @@ impl Meetings {
      *   While storing it in your database, store it as a **long** data type and **not as an integer**, as the Meeting IDs can be longer than 10 digits.
      * * `poll_id: &str` -- User's first name.
      */
-    pub async fn meeting_poll_get(
+    pub async fn poll_get(
         &self,
         meeting_id: i64,
         poll_id: &str,
@@ -722,7 +660,7 @@ impl Meetings {
      *   While storing it in your database, store it as a **long** data type and **not as an integer**, as the Meeting IDs can be longer than 10 digits.
      * * `poll_id: &str` -- User's first name.
      */
-    pub async fn meeting_poll_update(
+    pub async fn poll_update(
         &self,
         meeting_id: i64,
         poll_id: &str,
@@ -735,10 +673,7 @@ impl Meetings {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -762,7 +697,7 @@ impl Meetings {
      *   While storing it in your database, store it as a **long** data type and **not as an integer**, as the Meeting IDs can be longer than 10 digits.
      * * `poll_id: &str` -- User's first name.
      */
-    pub async fn meeting_poll_delete(&self, meeting_id: i64, poll_id: &str) -> Result<()> {
+    pub async fn poll_delete(&self, meeting_id: i64, poll_id: &str) -> Result<()> {
         let url = format!(
             "/meetings/{}/polls/{}",
             crate::progenitor_support::encode_path(&meeting_id.to_string()),
@@ -791,7 +726,7 @@ impl Meetings {
      *   
      *   While storing it in your database, store it as a **long** data type and **not as an integer**, as the Meeting IDs can be longer than 10 digits.
      */
-    pub async fn meeting_registrants_questions_get(
+    pub async fn registrants_questions_get(
         &self,
         meeting_id: i64,
     ) -> Result<crate::types::MeetingRegistrantQuestionsData> {
@@ -821,7 +756,7 @@ impl Meetings {
      *   
      *   While storing it in your database, store it as a **long** data type and **not as an integer**, as the Meeting IDs can be longer than 10 digits.
      */
-    pub async fn meeting_registrant_question_update(
+    pub async fn registrant_question_update(
         &self,
         meeting_id: i64,
         body: &crate::types::MeetingRegistrantQuestionsData,
@@ -832,10 +767,7 @@ impl Meetings {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -857,10 +789,7 @@ impl Meetings {
      *   
      *   While storing it in your database, store it as a **long** data type and **not as an integer**, as the Meeting IDs can be longer than 10 digits.
      */
-    pub async fn meeting_invitation(
-        &self,
-        meeting_id: i64,
-    ) -> Result<crate::types::MeetingInvitation> {
+    pub async fn invitation(&self, meeting_id: i64) -> Result<crate::types::MeetingInvitation> {
         let url = format!(
             "/meetings/{}/invitation",
             crate::progenitor_support::encode_path(&meeting_id.to_string()),
@@ -919,7 +848,7 @@ impl Meetings {
      *   
      *   While storing it in your database, store it as a **long** data type and **not as an integer**, as the Meeting IDs can be longer than 10 digits.
      */
-    pub async fn meeting_live_stream_update(
+    pub async fn live_stream_update(
         &self,
         meeting_id: &str,
         body: &crate::types::MeetingLiveStream,
@@ -930,10 +859,7 @@ impl Meetings {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -956,7 +882,7 @@ impl Meetings {
      *   
      *   While storing it in your database, store it as a **long** data type and **not as an integer**, as the Meeting IDs can be longer than 10 digits.
      */
-    pub async fn meeting_live_stream_status_update(
+    pub async fn live_stream_status_update(
         &self,
         meeting_id: i64,
         body: &crate::types::MeetingLiveStreamStatus,
@@ -967,10 +893,7 @@ impl Meetings {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -993,7 +916,7 @@ impl Meetings {
      *   
      *   If a UUID starts with "/" or contains "//" (example: "/ajXp112QmuoKj4854875==\"), you must **double encode** the UUID before making an API request.
      */
-    pub async fn list_past_meeting_polls(
+    pub async fn list_past_polls(
         &self,
         meeting_id: &str,
     ) -> Result<crate::types::ReportMeetingPollsResponse> {
@@ -1041,10 +964,7 @@ impl Meetings {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -1067,7 +987,7 @@ impl Meetings {
      *
      * * `meeting_id: &str` -- Unique identifier of the live meeting.
      */
-    pub async fn in_meeting_recording_control(
+    pub async fn recording_control(
         &self,
         meeting_id: &str,
         body: &crate::types::InMeetingRecordingControlRequest,
@@ -1078,10 +998,7 @@ impl Meetings {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -1092,7 +1009,7 @@ impl Meetings {
      *
      * Get the quality scores of a meeting.
      */
-    pub async fn meeting_quality_score(&self) -> Result<crate::types::Domains> {
+    pub async fn quality_score(&self) -> Result<crate::types::Domains> {
         let url = "/metrics/quality".to_string();
         self.client.get(&url, None).await
     }
@@ -1126,10 +1043,7 @@ impl Meetings {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -1147,7 +1061,7 @@ impl Meetings {
      *
      * * `user_id: &str` -- Unique identifier of the user. Retrieve the value of this field by calling the [List users](https://marketplace.zoom.us/docs/api-reference/zoom-api/users/users) API.
      */
-    pub async fn list_meeting_template(
+    pub async fn list_template(
         &self,
         user_id: &str,
     ) -> Result<crate::types::ListMeetingTemplatesResponseData> {
@@ -1174,7 +1088,7 @@ impl Meetings {
      *   
      *   While storing it in your database, store it as a **long** data type and **not as an integer**, as the Meeting IDs can be longer than 10 digits.
      */
-    pub async fn meeting_invite_links_create(
+    pub async fn invite_links_create(
         &self,
         meeting_id: i64,
         body: &crate::types::InviteLink,
@@ -1185,10 +1099,7 @@ impl Meetings {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 }
