@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct PhoneCallQueues {
-    client: Client,
+    pub client: Client,
 }
 
 impl PhoneCallQueues {
@@ -38,23 +38,17 @@ impl PhoneCallQueues {
         next_page_token: &str,
         page_size: i64,
     ) -> Result<Vec<crate::types::CallQueues>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !next_page_token.is_empty() {
-            query_args.push(format!("next_page_token={}", next_page_token));
+            query_args.push(("next_page_token".to_string(), next_page_token.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
+            query_args.push(("page_size".to_string(), page_size.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/phone/call_queues?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/phone/call_queues?{}", query_);
 
-        let resp: crate::types::ListCallQueuesResponse = self.client.get(&url, None).await.unwrap();
+        let resp: crate::types::ListCallQueuesResponse = self.client.get(&url, None).await?;
 
         // Return our response data.
         Ok(resp.call_queues)
@@ -80,8 +74,7 @@ impl PhoneCallQueues {
      */
     pub async fn list_all_call_queues(&self) -> Result<Vec<crate::types::CallQueues>> {
         let url = "/phone/call_queues".to_string();
-        let mut resp: crate::types::ListCallQueuesResponse =
-            self.client.get(&url, None).await.unwrap();
+        let mut resp: crate::types::ListCallQueuesResponse = self.client.get(&url, None).await?;
 
         let mut call_queues = resp.call_queues;
         let mut page = resp.next_page_token;
@@ -93,14 +86,12 @@ impl PhoneCallQueues {
                 resp = self
                     .client
                     .get(&format!("{}?next_page_token={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             } else {
                 resp = self
                     .client
                     .get(&format!("{}&next_page_token={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             }
 
             call_queues.append(&mut resp.call_queues);
@@ -138,10 +129,7 @@ impl PhoneCallQueues {
     ) -> Result<crate::types::CreateCallQueueResponse> {
         let url = "/phone/call_queues".to_string();
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -164,7 +152,7 @@ impl PhoneCallQueues {
      *
      * * `call_queue_id: &str` -- Unique Identifier of the Call Queue. This can be retrieved from [List Call Queues API](https://marketplace.zoom.us/docs/api-reference/zoom-api/phone-call-queues/listcallqueues).
      */
-    pub async fn get_a_call_queue(
+    pub async fn get_call_queue(
         &self,
         call_queue_id: &str,
     ) -> Result<crate::types::GetCallQueueResponse> {
@@ -197,7 +185,7 @@ impl PhoneCallQueues {
      *
      * * `call_queue_id: &str` -- Unique Identifier of the call queue.
      */
-    pub async fn delete_a_call_queue(&self, call_queue_id: &str) -> Result<()> {
+    pub async fn delete_call_queue(&self, call_queue_id: &str) -> Result<()> {
         let url = format!(
             "/phone/call_queues/{}",
             crate::progenitor_support::encode_path(&call_queue_id.to_string()),
@@ -236,10 +224,7 @@ impl PhoneCallQueues {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -262,7 +247,7 @@ impl PhoneCallQueues {
      *
      * * `call_queue_id: &str` -- Unique Identifier of the Call Queue.
      */
-    pub async fn assign_phone_to_call_queue(
+    pub async fn assign(
         &self,
         call_queue_id: &str,
         body: &crate::types::AddByocNumberResponse,
@@ -273,10 +258,7 @@ impl PhoneCallQueues {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -298,7 +280,7 @@ impl PhoneCallQueues {
      *
      * * `call_queue_id: &str` -- Unique Identifier of the Call Queue. This can be retrieved from List Call Queues API.
      */
-    pub async fn unassign_a_phone_num_call_queue(
+    pub async fn unassign_phone_num_call_queue(
         &self,
         call_queue_id: &str,
     ) -> Result<crate::types::Domains> {
@@ -361,7 +343,7 @@ impl PhoneCallQueues {
      *
      * * `call_queue_id: &str` -- Unique Identifier of the Call Queue.
      */
-    pub async fn add_members_to_call_queue(
+    pub async fn add_members_call_queue(
         &self,
         call_queue_id: &str,
         body: &crate::types::AddMembersCallQueueRequestData,
@@ -372,10 +354,7 @@ impl PhoneCallQueues {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -470,10 +449,7 @@ impl PhoneCallQueues {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -507,30 +483,28 @@ impl PhoneCallQueues {
         from: chrono::NaiveDate,
         to: chrono::NaiveDate,
     ) -> Result<Vec<crate::types::GetCallQueueRecordingsResponse>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("from={}", from));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !from.to_string().is_empty() {
+            query_args.push(("from".to_string(), from.to_string()));
+        }
         if !next_page_token.is_empty() {
-            query_args.push(format!("next_page_token={}", next_page_token));
+            query_args.push(("next_page_token".to_string(), next_page_token.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
+            query_args.push(("page_size".to_string(), page_size.to_string()));
         }
-        query_args.push(format!("to={}", to));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !to.to_string().is_empty() {
+            query_args.push(("to".to_string(), to.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/phone/call_queues/{}/recordings?{}",
             crate::progenitor_support::encode_path(&call_queue_id.to_string()),
-            query
+            query_
         );
 
         let resp: crate::types::GetCallQueueRecordingsResponseData =
-            self.client.get(&url, None).await.unwrap();
+            self.client.get(&url, None).await?;
 
         // Return our response data.
         Ok(resp.recordings)
@@ -558,24 +532,22 @@ impl PhoneCallQueues {
         from: chrono::NaiveDate,
         to: chrono::NaiveDate,
     ) -> Result<Vec<crate::types::GetCallQueueRecordingsResponse>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("from={}", from));
-        query_args.push(format!("to={}", to));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !from.to_string().is_empty() {
+            query_args.push(("from".to_string(), from.to_string()));
         }
+        if !to.to_string().is_empty() {
+            query_args.push(("to".to_string(), to.to_string()));
+        }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/phone/call_queues/{}/recordings?{}",
             crate::progenitor_support::encode_path(&call_queue_id.to_string()),
-            query
+            query_
         );
 
         let mut resp: crate::types::GetCallQueueRecordingsResponseData =
-            self.client.get(&url, None).await.unwrap();
+            self.client.get(&url, None).await?;
 
         let mut recordings = resp.recordings;
         let mut page = resp.next_page_token;
@@ -587,14 +559,12 @@ impl PhoneCallQueues {
                 resp = self
                     .client
                     .get(&format!("{}?next_page_token={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             } else {
                 resp = self
                     .client
                     .get(&format!("{}&next_page_token={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             }
 
             recordings.append(&mut resp.recordings);
