@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct PhoneSharedLineGroups {
-    client: Client,
+    pub client: Client,
 }
 
 impl PhoneSharedLineGroups {
@@ -38,24 +38,17 @@ impl PhoneSharedLineGroups {
         page_size: i64,
         next_page_token: &str,
     ) -> Result<Vec<crate::types::SharedLineGroups>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !next_page_token.is_empty() {
-            query_args.push(format!("next_page_token={}", next_page_token));
+            query_args.push(("next_page_token".to_string(), next_page_token.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
+            query_args.push(("page_size".to_string(), page_size.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/phone/shared_line_groups?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/phone/shared_line_groups?{}", query_);
 
-        let resp: crate::types::ListSharedLineGroupsResponse =
-            self.client.get(&url, None).await.unwrap();
+        let resp: crate::types::ListSharedLineGroupsResponse = self.client.get(&url, None).await?;
 
         // Return our response data.
         Ok(resp.shared_line_groups)
@@ -82,7 +75,7 @@ impl PhoneSharedLineGroups {
     pub async fn list_all_shared_line_groups(&self) -> Result<Vec<crate::types::SharedLineGroups>> {
         let url = "/phone/shared_line_groups".to_string();
         let mut resp: crate::types::ListSharedLineGroupsResponse =
-            self.client.get(&url, None).await.unwrap();
+            self.client.get(&url, None).await?;
 
         let mut shared_line_groups = resp.shared_line_groups;
         let mut page = resp.next_page_token;
@@ -94,14 +87,12 @@ impl PhoneSharedLineGroups {
                 resp = self
                     .client
                     .get(&format!("{}?next_page_token={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             } else {
                 resp = self
                     .client
                     .get(&format!("{}&next_page_token={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             }
 
             shared_line_groups.append(&mut resp.shared_line_groups);
@@ -132,16 +123,13 @@ impl PhoneSharedLineGroups {
      *  
      *  **[Rate Limit Label](https://marketplace.zoom.us/docs/api-reference/rate-limits#rate-limits):** `Light`
      */
-    pub async fn create_a_shared_line_group(
+    pub async fn create_shared_line_group(
         &self,
         body: &crate::types::CreateSharedLineGroupRequest,
     ) -> Result<()> {
         let url = "/phone/shared_line_groups".to_string();
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -165,7 +153,7 @@ impl PhoneSharedLineGroups {
      *
      * * `shared_line_group_id: &str` -- Unique Identifier of the Shared Line Group.
      */
-    pub async fn get_a_shared_line_group(
+    pub async fn get_shared_line_group(
         &self,
         shared_line_group_id: &str,
     ) -> Result<crate::types::GetSharedLineGroupResponse> {
@@ -196,7 +184,7 @@ impl PhoneSharedLineGroups {
      *
      * * `shared_line_group_id: &str` -- Unique Identifier of the shared line group that you would like to delete.
      */
-    pub async fn delete_a_shared_line_group(&self, shared_line_group_id: &str) -> Result<()> {
+    pub async fn delete_shared_line_group(&self, shared_line_group_id: &str) -> Result<()> {
         let url = format!(
             "/phone/shared_line_groups/{}",
             crate::progenitor_support::encode_path(&shared_line_group_id.to_string()),
@@ -223,7 +211,7 @@ impl PhoneSharedLineGroups {
      *
      * * `shared_line_group_id: &str` -- Unique identifier of the shared line group that is to be updated.
      */
-    pub async fn update_a_shared_line_group(
+    pub async fn update_shared_line_group(
         &self,
         shared_line_group_id: &str,
         body: &crate::types::UpdateSharedLineGroupRequest,
@@ -234,10 +222,7 @@ impl PhoneSharedLineGroups {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -262,7 +247,7 @@ impl PhoneSharedLineGroups {
      *
      * * `shared_line_group_id: &str` -- Unique Identifier of the shared line group.
      */
-    pub async fn add_members_to_shared_line_group(
+    pub async fn add_members_shared_line_group(
         &self,
         shared_line_group_id: &str,
         body: &crate::types::AddMembersSharedLineGroupRequestData,
@@ -273,10 +258,7 @@ impl PhoneSharedLineGroups {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -330,7 +312,7 @@ impl PhoneSharedLineGroups {
      * * `shared_line_group_id: &str` -- Unique Identifier of the shared line group from which you would like to remove a member.
      * * `member_id: &str` -- Unique identifier of the member who is to be removed.
      */
-    pub async fn delete_a_member_slg(
+    pub async fn delete_member_slg(
         &self,
         shared_line_group_id: &str,
         member_id: &str,
@@ -373,10 +355,7 @@ impl PhoneSharedLineGroups {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -426,7 +405,7 @@ impl PhoneSharedLineGroups {
      * * `shared_line_group_id: &str` -- Unique identifier of the shared line group from which you would like to unassign a phone number.
      * * `phone_number_id: &str` -- Unique identifier of the phone number which is to be unassigned. This can be retrieved from Get a Shared Line Group API.
      */
-    pub async fn delete_a_phone_number_slg(
+    pub async fn delete_phone_number_slg(
         &self,
         shared_line_group_id: &str,
         phone_number_id: &str,
