@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct Reports {
-    client: Client,
+    pub client: Client,
 }
 
 impl Reports {
@@ -29,26 +29,16 @@ impl Reports {
      * * `year: i64` -- Year for this report.
      * * `month: i64` -- Month for this report.
      */
-    pub async fn report_daily(
-        &self,
-        year: i64,
-        month: i64,
-    ) -> Result<crate::types::ReportDailyResponse> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+    pub async fn daily(&self, year: i64, month: i64) -> Result<crate::types::ReportDailyResponse> {
+        let mut query_args: Vec<(String, String)> = Default::default();
         if month > 0 {
-            query_args.push(format!("month={}", month));
+            query_args.push(("month".to_string(), month.to_string()));
         }
         if year > 0 {
-            query_args.push(format!("year={}", year));
+            query_args.push(("year".to_string(), year.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/report/daily?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/report/daily?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -75,7 +65,7 @@ impl Reports {
      * * `page_number: i64` -- The page number of the current page in the returned records.
      * * `next_page_token: &str` -- The next page token is used to paginate through large result sets. A next page token will be returned whenever the set of available results exceeds the current page size. The expiration period for this token is 15 minutes.
      */
-    pub async fn report_user(
+    pub async fn user(
         &self,
         type_: crate::types::ReportUsersType,
         from: chrono::NaiveDate,
@@ -84,27 +74,27 @@ impl Reports {
         page_number: i64,
         next_page_token: &str,
     ) -> Result<crate::types::Domains> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("from={}", from));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !from.to_string().is_empty() {
+            query_args.push(("from".to_string(), from.to_string()));
+        }
         if !next_page_token.is_empty() {
-            query_args.push(format!("next_page_token={}", next_page_token));
+            query_args.push(("next_page_token".to_string(), next_page_token.to_string()));
         }
         if page_number > 0 {
-            query_args.push(format!("page_number={}", page_number));
+            query_args.push(("page_number".to_string(), page_number.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
+            query_args.push(("page_size".to_string(), page_size.to_string()));
         }
-        query_args.push(format!("to={}", to));
-        query_args.push(format!("type={}", type_));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !to.to_string().is_empty() {
+            query_args.push(("to".to_string(), to.to_string()));
         }
-        let url = format!("/report/users?{}", query);
+        if !type_.to_string().is_empty() {
+            query_args.push(("type".to_string(), type_.to_string()));
+        }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/report/users?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -132,7 +122,7 @@ impl Reports {
      * * `next_page_token: &str` -- The next page token is used to paginate through large result sets. A next page token will be returned whenever the set of available results exceeds the current page size. The expiration period for this token is 15 minutes.
      * * `type_: crate::types::ReportMeetingsType` -- The meeting types: <br>`past` - Past meetings.<br>`pastOne` - Past one user meetings.
      */
-    pub async fn report_meeting(
+    pub async fn meeting(
         &self,
         user_id: &str,
         from: chrono::NaiveDate,
@@ -141,27 +131,27 @@ impl Reports {
         next_page_token: &str,
         type_: crate::types::ReportMeetingsType,
     ) -> Result<crate::types::ReportMeetingsResponseAllOf> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("from={}", from));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !from.to_string().is_empty() {
+            query_args.push(("from".to_string(), from.to_string()));
+        }
         if !next_page_token.is_empty() {
-            query_args.push(format!("next_page_token={}", next_page_token));
+            query_args.push(("next_page_token".to_string(), next_page_token.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
+            query_args.push(("page_size".to_string(), page_size.to_string()));
         }
-        query_args.push(format!("to={}", to));
-        query_args.push(format!("type={}", type_));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !to.to_string().is_empty() {
+            query_args.push(("to".to_string(), to.to_string()));
         }
+        if !type_.to_string().is_empty() {
+            query_args.push(("type".to_string(), type_.to_string()));
+        }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/report/users/{}/meetings?{}",
             crate::progenitor_support::encode_path(&user_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -186,7 +176,7 @@ impl Reports {
      *   
      *   If a UUID starts with "/" or contains "//" (example: "/ajXp112QmuoKj4854875==\"), you must **double encode** the UUID before making an API request.
      */
-    pub async fn report_meeting_details(
+    pub async fn meeting_details(
         &self,
         meeting_id: &str,
     ) -> Result<crate::types::ReportMeetingDetailsResponse> {
@@ -221,32 +211,28 @@ impl Reports {
      * * `next_page_token: &str` -- The next page token is used to paginate through large result sets. A next page token will be returned whenever the set of available results exceeds the current page size. The expiration period for this token is 15 minutes.
      * * `include_fields: crate::types::DashboardMeetingParticipantsIncludeFields` -- Provide `registrant_id` as the value for this field if you would like to see the registrant ID attribute in the response of this API call. A registrant ID is a unique identifier of a [meeting registrant](https://marketplace.zoom.us/docs/api-reference/zoom-api/meetings/meetingregistrants). This is not supported for `live` meeting types.
      */
-    pub async fn report_meeting_participant(
+    pub async fn meeting_participant(
         &self,
         meeting_id: &str,
         page_size: i64,
         next_page_token: &str,
         include_fields: crate::types::DashboardMeetingParticipantsIncludeFields,
     ) -> Result<crate::types::ReportMeetingParticipantsResponseAllOf> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("include_fields={}", include_fields));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !include_fields.to_string().is_empty() {
+            query_args.push(("include_fields".to_string(), include_fields.to_string()));
+        }
         if !next_page_token.is_empty() {
-            query_args.push(format!("next_page_token={}", next_page_token));
+            query_args.push(("next_page_token".to_string(), next_page_token.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("page_size".to_string(), page_size.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/report/meetings/{}/participants?{}",
             crate::progenitor_support::encode_path(&meeting_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -271,7 +257,7 @@ impl Reports {
      *   
      *   If a UUID starts with "/" or contains "//" (example: "/ajXp112QmuoKj4854875==\"), you must **double encode** the UUID before making an API request.
      */
-    pub async fn report_meeting_polls(
+    pub async fn meeting_polls(
         &self,
         meeting_id: &str,
     ) -> Result<crate::types::ReportMeetingPollsResponse> {
@@ -301,7 +287,7 @@ impl Reports {
      *   
      *   If a UUID starts with "/" or contains "//" (example: "/ajXp112QmuoKj4854875==\"), you must **double encode** the UUID before making an API request.
      */
-    pub async fn report_webinar_details(
+    pub async fn webinar_details(
         &self,
         webinar_id: &str,
     ) -> Result<crate::types::ReportMeetingDetailsResponse> {
@@ -334,32 +320,28 @@ impl Reports {
      * * `next_page_token: &str` -- The next page token is used to paginate through large result sets. A next page token will be returned whenever the set of available results exceeds the current page size. The expiration period for this token is 15 minutes.
      * * `include_fields: crate::types::DashboardMeetingParticipantsIncludeFields` -- Provide `registrant_id` as the value for this field if you would like to see the registrant ID attribute in the response of this API call. A registrant ID is a unique identifier of a [meeting registrant](https://marketplace.zoom.us/docs/api-reference/zoom-api/meetings/meetingregistrants). This is not supported for `live` meeting types.
      */
-    pub async fn report_webinar_participant(
+    pub async fn webinar_participant(
         &self,
         webinar_id: &str,
         page_size: i64,
         next_page_token: &str,
         include_fields: crate::types::DashboardMeetingParticipantsIncludeFields,
     ) -> Result<crate::types::ReportWebinarParticipantsResponseAllOf> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("include_fields={}", include_fields));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !include_fields.to_string().is_empty() {
+            query_args.push(("include_fields".to_string(), include_fields.to_string()));
+        }
         if !next_page_token.is_empty() {
-            query_args.push(format!("next_page_token={}", next_page_token));
+            query_args.push(("next_page_token".to_string(), next_page_token.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("page_size".to_string(), page_size.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/report/webinars/{}/participants?{}",
             crate::progenitor_support::encode_path(&webinar_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -383,7 +365,7 @@ impl Reports {
      *   
      *   If a UUID starts with "/" or contains "//" (example: "/ajXp112QmuoKj4854875==\"), you must **double encode** the UUID before making an API request.
      */
-    pub async fn report_webinar_polls(
+    pub async fn webinar_polls(
         &self,
         webinar_id: &str,
     ) -> Result<crate::types::ReportMeetingPollsResponse> {
@@ -415,7 +397,7 @@ impl Reports {
      *   
      *   If a UUID starts with "/" or contains "//" (example: "/ajXp112QmuoKj4854875==\"), you must **double encode** the UUID before making an API request.
      */
-    pub async fn report_webinar_qa(
+    pub async fn webinar_qa(
         &self,
         webinar_id: &str,
     ) -> Result<crate::types::ReportWebinarQaResponse> {
@@ -453,7 +435,7 @@ impl Reports {
      *   The page number of the current page in the returned records.
      * * `next_page_token: &str` -- The next page token is used to paginate through large result sets. A next page token will be returned whenever the set of available results exceeds the current page size. The expiration period for this token is 15 minutes.
      */
-    pub async fn report_telephone(
+    pub async fn telephone(
         &self,
         type_: &str,
         query_date_type: crate::types::QueryDateType,
@@ -463,30 +445,30 @@ impl Reports {
         page_number: i64,
         next_page_token: &str,
     ) -> Result<crate::types::Domains> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("from={}", from));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !from.to_string().is_empty() {
+            query_args.push(("from".to_string(), from.to_string()));
+        }
         if !next_page_token.is_empty() {
-            query_args.push(format!("next_page_token={}", next_page_token));
+            query_args.push(("next_page_token".to_string(), next_page_token.to_string()));
         }
         if page_number > 0 {
-            query_args.push(format!("page_number={}", page_number));
+            query_args.push(("page_number".to_string(), page_number.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
+            query_args.push(("page_size".to_string(), page_size.to_string()));
+        }
+        if !query_date_type.to_string().is_empty() {
+            query_args.push(("query_date_type".to_string(), query_date_type.to_string()));
+        }
+        if !to.to_string().is_empty() {
+            query_args.push(("to".to_string(), to.to_string()));
         }
-        query_args.push(format!("query_date_type={}", query_date_type));
-        query_args.push(format!("to={}", to));
         if !type_.is_empty() {
-            query_args.push(format!("type={}", type_));
+            query_args.push(("type".to_string(), type_.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/report/telephone?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/report/telephone?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -508,22 +490,20 @@ impl Reports {
      * * `from: chrono::NaiveDate` -- Start date in 'yyyy-mm-dd' format. The date range defined by the "from" and "to" parameters should only be one month as the report includes only one month worth of data at once.
      * * `to: chrono::NaiveDate` -- Start Date.
      */
-    pub async fn report_cloud_recording(
+    pub async fn cloud_recording(
         &self,
         from: chrono::NaiveDate,
         to: chrono::NaiveDate,
     ) -> Result<crate::types::ReportCloudRecordingResponseAllOf> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("from={}", from));
-        query_args.push(format!("to={}", to));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !from.to_string().is_empty() {
+            query_args.push(("from".to_string(), from.to_string()));
         }
-        let url = format!("/report/cloud_recording?{}", query);
+        if !to.to_string().is_empty() {
+            query_args.push(("to".to_string(), to.to_string()));
+        }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/report/cloud_recording?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -551,7 +531,7 @@ impl Reports {
      *  Filter your response by a category type to see reports for a specific category.
      *  The value for this field can be one of the following:<br> `all`<br>`user`<br>`user_settings`<br>`account`<br>`billing`<br>`im`<br>`recording`<br>`phone_contacts`<br>`webinar`<br>`sub_account`<br>`role`<br>`zoom_rooms`.
      */
-    pub async fn report_operation_log(
+    pub async fn operation_log(
         &self,
         from: chrono::NaiveDate,
         to: chrono::NaiveDate,
@@ -559,24 +539,24 @@ impl Reports {
         next_page_token: &str,
         category_type: crate::types::CategoryType,
     ) -> Result<crate::types::ReportOperationLogsResponseAllOf> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("category_type={}", category_type));
-        query_args.push(format!("from={}", from));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !category_type.to_string().is_empty() {
+            query_args.push(("category_type".to_string(), category_type.to_string()));
+        }
+        if !from.to_string().is_empty() {
+            query_args.push(("from".to_string(), from.to_string()));
+        }
         if !next_page_token.is_empty() {
-            query_args.push(format!("next_page_token={}", next_page_token));
+            query_args.push(("next_page_token".to_string(), next_page_token.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
+            query_args.push(("page_size".to_string(), page_size.to_string()));
         }
-        query_args.push(format!("to={}", to));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !to.to_string().is_empty() {
+            query_args.push(("to".to_string(), to.to_string()));
         }
-        let url = format!("/report/operationlogs?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/report/operationlogs?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -600,33 +580,31 @@ impl Reports {
      * * `page_size: i64` -- The number of records to be returned within a single API call.
      * * `next_page_token: &str` -- Next page token is used to paginate through large result sets.
      */
-    pub async fn report_sign_in_out_activities(
+    pub async fn sign_out_activities(
         &self,
         from: chrono::NaiveDate,
         to: chrono::NaiveDate,
         page_size: i64,
         next_page_token: &str,
     ) -> Result<Vec<crate::types::ActivityLogs>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("from={}", from));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !from.to_string().is_empty() {
+            query_args.push(("from".to_string(), from.to_string()));
+        }
         if !next_page_token.is_empty() {
-            query_args.push(format!("next_page_token={}", next_page_token));
+            query_args.push(("next_page_token".to_string(), next_page_token.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
+            query_args.push(("page_size".to_string(), page_size.to_string()));
         }
-        query_args.push(format!("to={}", to));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !to.to_string().is_empty() {
+            query_args.push(("to".to_string(), to.to_string()));
         }
-        let url = format!("/report/activities?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/report/activities?{}", query_);
 
         let resp: crate::types::ReportSignInOutActivitiesResponse =
-            self.client.get(&url, None).await.unwrap();
+            self.client.get(&url, None).await?;
 
         // Return our response data.
         Ok(resp.activity_logs)
@@ -637,7 +615,7 @@ impl Reports {
      *
      * This function performs a `GET` to the `/report/activities` endpoint.
      *
-     * As opposed to `report_sign_in_out_activities`, this function returns all the pages of the request at once.
+     * As opposed to `sign_out_activities`, this function returns all the pages of the request at once.
      *
      * Retrieve a list of sign in / sign out activity logs [report](https://support.zoom.us/hc/en-us/articles/201363213-Getting-Started-with-Reports) of users under a Zoom account.<br>
      * **Prerequisites**<br>
@@ -646,25 +624,23 @@ impl Reports {
      *  
      *  **[Rate Limit Label](https://marketplace.zoom.us/docs/api-reference/rate-limits#rate-limits):** `Heavy`
      */
-    pub async fn get_all_report_sign_in_out_activities(
+    pub async fn get_all_sign_out_activities(
         &self,
         from: chrono::NaiveDate,
         to: chrono::NaiveDate,
     ) -> Result<Vec<crate::types::ActivityLogs>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("from={}", from));
-        query_args.push(format!("to={}", to));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !from.to_string().is_empty() {
+            query_args.push(("from".to_string(), from.to_string()));
         }
-        let url = format!("/report/activities?{}", query);
+        if !to.to_string().is_empty() {
+            query_args.push(("to".to_string(), to.to_string()));
+        }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/report/activities?{}", query_);
 
         let mut resp: crate::types::ReportSignInOutActivitiesResponse =
-            self.client.get(&url, None).await.unwrap();
+            self.client.get(&url, None).await?;
 
         let mut activity_logs = resp.activity_logs;
         let mut page = resp.next_page_token;
@@ -676,14 +652,12 @@ impl Reports {
                 resp = self
                     .client
                     .get(&format!("{}?next_page_token={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             } else {
                 resp = self
                     .client
                     .get(&format!("{}&next_page_token={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             }
 
             activity_logs.append(&mut resp.activity_logs);
@@ -713,7 +687,7 @@ impl Reports {
      *  
      *  **[Rate Limit Label](https://marketplace.zoom.us/docs/api-reference/rate-limits#rate-limits):** `Heavy`
      */
-    pub async fn get_billing_report(&self) -> Result<crate::types::GetBillingReportResponse> {
+    pub async fn get_billing(&self) -> Result<crate::types::GetBillingReportResponse> {
         let url = "/report/billing".to_string();
         self.client.get(&url, None).await
     }
@@ -743,18 +717,12 @@ impl Reports {
         &self,
         billing_id: &str,
     ) -> Result<crate::types::GetBillingInvoicesReportsResponse> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !billing_id.is_empty() {
-            query_args.push(format!("billing_id={}", billing_id));
+            query_args.push(("billing_id".to_string(), billing_id.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/report/billing/invoices?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/report/billing/invoices?{}", query_);
 
         self.client.get(&url, None).await
     }
