@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct Roles {
-    client: Client,
+    pub client: Client,
 }
 
 impl Roles {
@@ -47,13 +47,10 @@ impl Roles {
      *  
      *  **[Rate Limit Label](https://marketplace.zoom.us/docs/api-reference/rate-limits#rate-limits):** `Light`
      */
-    pub async fn create_role(&self, body: &crate::types::CreateRoleRequest) -> Result<()> {
+    pub async fn create(&self, body: &crate::types::CreateRoleRequest) -> Result<()> {
         let url = "/roles".to_string();
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -80,7 +77,7 @@ impl Roles {
      * * `next_page_token: &str` -- The next page token is used to paginate through large result sets. A next page token will be returned whenever the set of available results exceeds the current page size. The expiration period for this token is 15 minutes.
      * * `page_size: i64` -- The number of records returned within a single API call.
      */
-    pub async fn role_members(
+    pub async fn members(
         &self,
         role_id: &str,
         page_count: &str,
@@ -88,33 +85,27 @@ impl Roles {
         next_page_token: &str,
         page_size: i64,
     ) -> Result<Vec<crate::types::Domains>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !next_page_token.is_empty() {
-            query_args.push(format!("next_page_token={}", next_page_token));
+            query_args.push(("next_page_token".to_string(), next_page_token.to_string()));
         }
         if !page_count.is_empty() {
-            query_args.push(format!("page_count={}", page_count));
+            query_args.push(("page_count".to_string(), page_count.to_string()));
         }
         if page_number > 0 {
-            query_args.push(format!("page_number={}", page_number));
+            query_args.push(("page_number".to_string(), page_number.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("page_size".to_string(), page_size.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/roles/{}/members?{}",
             crate::progenitor_support::encode_path(&role_id.to_string()),
-            query
+            query_
         );
 
-        let resp: crate::types::RoleMembersList = self.client.get(&url, None).await.unwrap();
+        let resp: crate::types::RoleMembersList = self.client.get(&url, None).await?;
 
         // Return our response data.
         Ok(resp.members)
@@ -125,7 +116,7 @@ impl Roles {
      *
      * This function performs a `GET` to the `/roles/{roleId}/members` endpoint.
      *
-     * As opposed to `role_members`, this function returns all the pages of the request at once.
+     * As opposed to `members`, this function returns all the pages of the request at once.
      *
      * User [roles](https://support.zoom.us/hc/en-us/articles/115001078646-Role-Based-Access-Control) can have a set of permissions that allows access only to the pages a user needs to view or edit. Use this API to list all the members that are assigned a specific role.
      *
@@ -134,29 +125,23 @@ impl Roles {
      *  **[Rate Limit Label](https://marketplace.zoom.us/docs/api-reference/rate-limits#rate-limits):** `Medium`<br>**Prerequisites:**<br>
      * * A Pro or a higher plan.
      */
-    pub async fn get_all_role_members(
+    pub async fn get_all_members(
         &self,
         role_id: &str,
         page_count: &str,
     ) -> Result<Vec<crate::types::Domains>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !page_count.is_empty() {
-            query_args.push(format!("page_count={}", page_count));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("page_count".to_string(), page_count.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/roles/{}/members?{}",
             crate::progenitor_support::encode_path(&role_id.to_string()),
-            query
+            query_
         );
 
-        let mut resp: crate::types::RoleMembersList = self.client.get(&url, None).await.unwrap();
+        let mut resp: crate::types::RoleMembersList = self.client.get(&url, None).await?;
 
         let mut members = resp.members;
         let mut page = resp.next_page_token;
@@ -168,14 +153,12 @@ impl Roles {
                 resp = self
                     .client
                     .get(&format!("{}?next_page_token={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             } else {
                 resp = self
                     .client
                     .get(&format!("{}&next_page_token={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             }
 
             members.append(&mut resp.members);
@@ -208,7 +191,7 @@ impl Roles {
      *
      * * `role_id: &str` -- User's first name.
      */
-    pub async fn add_role_members(
+    pub async fn add_members(
         &self,
         role_id: &str,
         body: &crate::types::AddRoleMembersRequest,
@@ -219,10 +202,7 @@ impl Roles {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -244,7 +224,7 @@ impl Roles {
      * * `role_id: &str` -- User's first name.
      * * `member_id: &str` -- User's first name.
      */
-    pub async fn role_member_delete(&self, role_id: &str, member_id: &str) -> Result<()> {
+    pub async fn member_delete(&self, role_id: &str, member_id: &str) -> Result<()> {
         let url = format!(
             "/roles/{}/members/{}",
             crate::progenitor_support::encode_path(&role_id.to_string()),
@@ -274,7 +254,7 @@ impl Roles {
      *
      * * `role_id: &str` -- User's first name.
      */
-    pub async fn get_role_information(
+    pub async fn get_information(
         &self,
         role_id: &str,
     ) -> Result<crate::types::GetRoleInformationResponse> {
@@ -306,7 +286,7 @@ impl Roles {
      *
      * * `role_id: &str` -- User's first name.
      */
-    pub async fn delete_role(&self, role_id: &str) -> Result<()> {
+    pub async fn delete(&self, role_id: &str) -> Result<()> {
         let url = format!(
             "/roles/{}",
             crate::progenitor_support::encode_path(&role_id.to_string()),
@@ -333,7 +313,7 @@ impl Roles {
      *
      * * `role_id: &str` -- User's first name.
      */
-    pub async fn update_role(
+    pub async fn update(
         &self,
         role_id: &str,
         body: &crate::types::UpdateRoleRequest,
@@ -344,10 +324,7 @@ impl Roles {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 }
