@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct Rooms {
-    client: Client,
+    pub client: Client,
 }
 
 impl Rooms {
@@ -41,32 +41,29 @@ impl Rooms {
         next_page_token: &str,
         location_id: &str,
     ) -> Result<Vec<crate::types::ListZoomRoomsResponse>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !location_id.is_empty() {
-            query_args.push(format!("location_id={}", location_id));
+            query_args.push(("location_id".to_string(), location_id.to_string()));
         }
         if !next_page_token.is_empty() {
-            query_args.push(format!("next_page_token={}", next_page_token));
+            query_args.push(("next_page_token".to_string(), next_page_token.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
+            query_args.push(("page_size".to_string(), page_size.to_string()));
+        }
+        if !status.to_string().is_empty() {
+            query_args.push(("status".to_string(), status.to_string()));
+        }
+        if !type_.to_string().is_empty() {
+            query_args.push(("type".to_string(), type_.to_string()));
         }
-        query_args.push(format!("status={}", status));
-        query_args.push(format!("type={}", type_));
         if unassigned_rooms {
-            query_args.push(format!("unassigned_rooms={}", unassigned_rooms));
+            query_args.push(("unassigned_rooms".to_string(), unassigned_rooms.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/rooms?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/rooms?{}", query_);
 
-        let resp: crate::types::ListZoomRoomsResponseData =
-            self.client.get(&url, None).await.unwrap();
+        let resp: crate::types::ListZoomRoomsResponseData = self.client.get(&url, None).await?;
 
         // Return our response data.
         Ok(resp.rooms)
@@ -92,26 +89,23 @@ impl Rooms {
         unassigned_rooms: bool,
         location_id: &str,
     ) -> Result<Vec<crate::types::ListZoomRoomsResponse>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !location_id.is_empty() {
-            query_args.push(format!("location_id={}", location_id));
+            query_args.push(("location_id".to_string(), location_id.to_string()));
+        }
+        if !status.to_string().is_empty() {
+            query_args.push(("status".to_string(), status.to_string()));
+        }
+        if !type_.to_string().is_empty() {
+            query_args.push(("type".to_string(), type_.to_string()));
         }
-        query_args.push(format!("status={}", status));
-        query_args.push(format!("type={}", type_));
         if unassigned_rooms {
-            query_args.push(format!("unassigned_rooms={}", unassigned_rooms));
+            query_args.push(("unassigned_rooms".to_string(), unassigned_rooms.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/rooms?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/rooms?{}", query_);
 
-        let mut resp: crate::types::ListZoomRoomsResponseData =
-            self.client.get(&url, None).await.unwrap();
+        let mut resp: crate::types::ListZoomRoomsResponseData = self.client.get(&url, None).await?;
 
         let mut rooms = resp.rooms;
         let mut page = resp.next_page_token;
@@ -123,14 +117,12 @@ impl Rooms {
                 resp = self
                     .client
                     .get(&format!("{}?next_page_token={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             } else {
                 resp = self
                     .client
                     .get(&format!("{}&next_page_token={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             }
 
             rooms.append(&mut resp.rooms);
@@ -157,16 +149,13 @@ impl Rooms {
      * **Scopes**: `room:write:admin`<br>
      *  **[Rate Limit Label](https://marketplace.zoom.us/docs/api-reference/rate-limits#rate-limits):** `Medium`
      */
-    pub async fn add_a_room(
+    pub async fn add(
         &self,
         body: &crate::types::AddRoomRequest,
     ) -> Result<crate::types::AddRoomResponse> {
         let url = "/rooms".to_string();
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -214,7 +203,7 @@ impl Rooms {
      *
      * * `room_id: &str` -- Unique Identifier of a Zoom Room.
      */
-    pub async fn delete_a_zoom_room(&self, room_id: &str) -> Result<crate::types::Domains> {
+    pub async fn delete_zoom(&self, room_id: &str) -> Result<crate::types::Domains> {
         let url = format!(
             "/rooms/{}",
             crate::progenitor_support::encode_path(&room_id.to_string()),
@@ -239,7 +228,7 @@ impl Rooms {
      *
      * * `room_id: &str` -- Unique Identifier of a Zoom Room.
      */
-    pub async fn update_room_profile(
+    pub async fn update_profile(
         &self,
         room_id: &str,
         body: &crate::types::UpdateRoomProfileRequest,
@@ -250,10 +239,7 @@ impl Rooms {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -281,21 +267,15 @@ impl Rooms {
         room_id: &str,
         setting_type: &str,
     ) -> Result<crate::types::Domains> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !setting_type.is_empty() {
-            query_args.push(format!("setting_type={}", setting_type));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("setting_type".to_string(), setting_type.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/rooms/{}/settings?{}",
             crate::progenitor_support::encode_path(&room_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -321,21 +301,15 @@ impl Rooms {
      *   `signage`: Digital signage settings applied on the Zoom Room.
      */
     pub async fn update_zr_settings(&self, room_id: &str, setting_type: &str) -> Result<()> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !setting_type.is_empty() {
-            query_args.push(format!("setting_type={}", setting_type));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("setting_type".to_string(), setting_type.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/rooms/{}/settings?{}",
             crate::progenitor_support::encode_path(&room_id.to_string()),
-            query
+            query_
         );
 
         self.client.patch(&url, None).await
@@ -397,10 +371,7 @@ impl Rooms {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -421,17 +392,14 @@ impl Rooms {
      *
      * * `id: &str` -- User's first name.
      */
-    pub async fn check_in(&self, id: &str, body: &crate::types::CheckInRoomsRequest) -> Result<()> {
+    pub async fn check(&self, id: &str, body: &crate::types::CheckInRoomsRequest) -> Result<()> {
         let url = format!(
             "/rooms/{}/events",
             crate::progenitor_support::encode_path(&id.to_string()),
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -465,30 +433,24 @@ impl Rooms {
         page_size: i64,
         next_page_token: &str,
     ) -> Result<Vec<crate::types::Site>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !folder_id.is_empty() {
-            query_args.push(format!("folder_id={}", folder_id));
+            query_args.push(("folder_id".to_string(), folder_id.to_string()));
         }
         if !next_page_token.is_empty() {
-            query_args.push(format!("next_page_token={}", next_page_token));
+            query_args.push(("next_page_token".to_string(), next_page_token.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
+            query_args.push(("page_size".to_string(), page_size.to_string()));
         }
         if !type_.is_empty() {
-            query_args.push(format!("type={}", type_));
+            query_args.push(("type".to_string(), type_.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/rooms/digital_signage?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/rooms/digital_signage?{}", query_);
 
         let resp: crate::types::ListDigitalSignageContentResponse =
-            self.client.get(&url, None).await.unwrap();
+            self.client.get(&url, None).await?;
 
         // Return our response data.
         Ok(resp.contents)
@@ -515,24 +477,18 @@ impl Rooms {
         type_: &str,
         folder_id: &str,
     ) -> Result<Vec<crate::types::Site>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !folder_id.is_empty() {
-            query_args.push(format!("folder_id={}", folder_id));
+            query_args.push(("folder_id".to_string(), folder_id.to_string()));
         }
         if !type_.is_empty() {
-            query_args.push(format!("type={}", type_));
+            query_args.push(("type".to_string(), type_.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/rooms/digital_signage?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/rooms/digital_signage?{}", query_);
 
         let mut resp: crate::types::ListDigitalSignageContentResponse =
-            self.client.get(&url, None).await.unwrap();
+            self.client.get(&url, None).await?;
 
         let mut contents = resp.contents;
         let mut page = resp.next_page_token;
@@ -544,14 +500,12 @@ impl Rooms {
                 resp = self
                     .client
                     .get(&format!("{}?next_page_token={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             } else {
                 resp = self
                     .client
                     .get(&format!("{}&next_page_token={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             }
 
             contents.append(&mut resp.contents);
