@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct SipConnectedAudio {
-    client: Client,
+    pub client: Client,
 }
 
 impl SipConnectedAudio {
@@ -59,10 +59,7 @@ impl SipConnectedAudio {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -95,10 +92,7 @@ impl SipConnectedAudio {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -178,10 +172,7 @@ impl SipConnectedAudio {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -265,10 +256,7 @@ impl SipConnectedAudio {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -327,28 +315,21 @@ impl SipConnectedAudio {
         page_size: i64,
         next_page_token: &str,
     ) -> Result<Vec<crate::types::InternalNumbers>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !next_page_token.is_empty() {
-            query_args.push(format!("next_page_token={}", next_page_token));
+            query_args.push(("next_page_token".to_string(), next_page_token.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("page_size".to_string(), page_size.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/accounts/{}/sip_trunk/internal_numbers?{}",
             crate::progenitor_support::encode_path(&account_id.to_string()),
-            query
+            query_
         );
 
-        let resp: crate::types::ListInternalNumbersResponse =
-            self.client.get(&url, None).await.unwrap();
+        let resp: crate::types::ListInternalNumbersResponse = self.client.get(&url, None).await?;
 
         // Return our response data.
         Ok(resp.internal_numbers)
@@ -379,7 +360,7 @@ impl SipConnectedAudio {
         );
 
         let mut resp: crate::types::ListInternalNumbersResponse =
-            self.client.get(&url, None).await.unwrap();
+            self.client.get(&url, None).await?;
 
         let mut internal_numbers = resp.internal_numbers;
         let mut page = resp.next_page_token;
@@ -391,14 +372,12 @@ impl SipConnectedAudio {
                 resp = self
                     .client
                     .get(&format!("{}?next_page_token={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             } else {
                 resp = self
                     .client
                     .get(&format!("{}&next_page_token={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             }
 
             internal_numbers.append(&mut resp.internal_numbers);
@@ -441,10 +420,7 @@ impl SipConnectedAudio {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
