@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct SipPhone {
-    client: Client,
+    pub client: Client,
 }
 
 impl SipPhone {
@@ -41,29 +41,23 @@ impl SipPhone {
         page_size: i64,
         next_page_token: &str,
     ) -> Result<Vec<crate::types::Phones>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !next_page_token.is_empty() {
-            query_args.push(format!("next_page_token={}", next_page_token));
+            query_args.push(("next_page_token".to_string(), next_page_token.to_string()));
         }
         if page_number > 0 {
-            query_args.push(format!("page_number={}", page_number));
+            query_args.push(("page_number".to_string(), page_number.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
+            query_args.push(("page_size".to_string(), page_size.to_string()));
         }
         if !search_key.is_empty() {
-            query_args.push(format!("search_key={}", search_key));
+            query_args.push(("search_key".to_string(), search_key.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/sip_phones?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/sip_phones?{}", query_);
 
-        let resp: crate::types::ListSipPhonesResponse = self.client.get(&url, None).await.unwrap();
+        let resp: crate::types::ListSipPhonesResponse = self.client.get(&url, None).await?;
 
         // Return our response data.
         Ok(resp.phones)
@@ -84,21 +78,14 @@ impl SipPhone {
      *
      */
     pub async fn list_all(&self, search_key: &str) -> Result<Vec<crate::types::Phones>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !search_key.is_empty() {
-            query_args.push(format!("search_key={}", search_key));
+            query_args.push(("search_key".to_string(), search_key.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/sip_phones?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/sip_phones?{}", query_);
 
-        let mut resp: crate::types::ListSipPhonesResponse =
-            self.client.get(&url, None).await.unwrap();
+        let mut resp: crate::types::ListSipPhonesResponse = self.client.get(&url, None).await?;
 
         let mut phones = resp.phones;
         let mut page = resp.next_page_token;
@@ -110,14 +97,12 @@ impl SipPhone {
                 resp = self
                     .client
                     .get(&format!("{}?next_page_token={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             } else {
                 resp = self
                     .client
                     .get(&format!("{}&next_page_token={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             }
 
             phones.append(&mut resp.phones);
@@ -150,10 +135,7 @@ impl SipPhone {
     pub async fn create(&self, body: &crate::types::CreateSipPhoneRequest) -> Result<()> {
         let url = "/sip_phones".to_string();
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -209,10 +191,7 @@ impl SipPhone {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 }
