@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct Users {
-    client: Client,
+    pub client: Client,
 }
 
 impl Users {
@@ -46,31 +46,29 @@ impl Users {
         include_fields: crate::types::UsersIncludeFields,
         next_page_token: &str,
     ) -> Result<Vec<crate::types::UsersResponse>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("include_fields={}", include_fields));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !include_fields.to_string().is_empty() {
+            query_args.push(("include_fields".to_string(), include_fields.to_string()));
+        }
         if !next_page_token.is_empty() {
-            query_args.push(format!("next_page_token={}", next_page_token));
+            query_args.push(("next_page_token".to_string(), next_page_token.to_string()));
         }
         if !page_number.is_empty() {
-            query_args.push(format!("page_number={}", page_number));
+            query_args.push(("page_number".to_string(), page_number.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
+            query_args.push(("page_size".to_string(), page_size.to_string()));
         }
         if !role_id.is_empty() {
-            query_args.push(format!("role_id={}", role_id));
+            query_args.push(("role_id".to_string(), role_id.to_string()));
         }
-        query_args.push(format!("status={}", status));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !status.to_string().is_empty() {
+            query_args.push(("status".to_string(), status.to_string()));
         }
-        let url = format!("/users?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/users?{}", query_);
 
-        let resp: crate::types::UsersResponseData = self.client.get(&url, None).await.unwrap();
+        let resp: crate::types::UsersResponseData = self.client.get(&url, None).await?;
 
         // Return our response data.
         Ok(resp.users)
@@ -93,22 +91,20 @@ impl Users {
         role_id: &str,
         include_fields: crate::types::UsersIncludeFields,
     ) -> Result<Vec<crate::types::UsersResponse>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("include_fields={}", include_fields));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !include_fields.to_string().is_empty() {
+            query_args.push(("include_fields".to_string(), include_fields.to_string()));
+        }
         if !role_id.is_empty() {
-            query_args.push(format!("role_id={}", role_id));
+            query_args.push(("role_id".to_string(), role_id.to_string()));
         }
-        query_args.push(format!("status={}", status));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !status.to_string().is_empty() {
+            query_args.push(("status".to_string(), status.to_string()));
         }
-        let url = format!("/users?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/users?{}", query_);
 
-        let mut resp: crate::types::UsersResponseData = self.client.get(&url, None).await.unwrap();
+        let mut resp: crate::types::UsersResponseData = self.client.get(&url, None).await?;
 
         let mut users = resp.users;
         let mut page = resp.next_page_token;
@@ -120,14 +116,12 @@ impl Users {
                 resp = self
                     .client
                     .get(&format!("{}?next_page_token={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             } else {
                 resp = self
                     .client
                     .get(&format!("{}&next_page_token={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             }
 
             users.append(&mut resp.users);
@@ -155,16 +149,13 @@ impl Users {
      *  
      *  **[Rate Limit Label](https://marketplace.zoom.us/docs/api-reference/rate-limits#rate-limits):** `Light`
      */
-    pub async fn user_create(
+    pub async fn create(
         &self,
         body: &crate::types::UserCreateRequest,
     ) -> Result<crate::types::UserCreateResponse> {
         let url = "/users".to_string();
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -197,22 +188,18 @@ impl Users {
         login_type: crate::types::LoginType,
         encrypted_email: bool,
     ) -> Result<crate::types::UserResponseAllOf> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if encrypted_email {
-            query_args.push(format!("encrypted_email={}", encrypted_email));
+            query_args.push(("encrypted_email".to_string(), encrypted_email.to_string()));
         }
-        query_args.push(format!("login_type={}", login_type));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !login_type.to_string().is_empty() {
+            query_args.push(("login_type".to_string(), login_type.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/users/{}?{}",
             crate::progenitor_support::encode_path(&user_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -240,7 +227,7 @@ impl Users {
      * * `transfer_webinar: bool` -- Enable/disable the option for a sub account to use shared [Virtual Room Connector(s)](https://support.zoom.us/hc/en-us/articles/202134758-Getting-Started-With-Virtual-Room-Connector) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
      * * `transfer_recording: bool` -- Enable/disable the option for a sub account to use shared [Virtual Room Connector(s)](https://support.zoom.us/hc/en-us/articles/202134758-Getting-Started-With-Virtual-Room-Connector) that are set up by the master account. Virtual Room Connectors can only be used by On-prem users.
      */
-    pub async fn user_delete(
+    pub async fn delete(
         &self,
         user_id: &str,
         action: crate::types::UserDeleteAction,
@@ -249,31 +236,30 @@ impl Users {
         transfer_webinar: bool,
         transfer_recording: bool,
     ) -> Result<()> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("action={}", action));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !action.to_string().is_empty() {
+            query_args.push(("action".to_string(), action.to_string()));
+        }
         if !transfer_email.is_empty() {
-            query_args.push(format!("transfer_email={}", transfer_email));
+            query_args.push(("transfer_email".to_string(), transfer_email.to_string()));
         }
         if transfer_meeting {
-            query_args.push(format!("transfer_meeting={}", transfer_meeting));
+            query_args.push(("transfer_meeting".to_string(), transfer_meeting.to_string()));
         }
         if transfer_recording {
-            query_args.push(format!("transfer_recording={}", transfer_recording));
+            query_args.push((
+                "transfer_recording".to_string(),
+                transfer_recording.to_string(),
+            ));
         }
         if transfer_webinar {
-            query_args.push(format!("transfer_webinar={}", transfer_webinar));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("transfer_webinar".to_string(), transfer_webinar.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/users/{}?{}",
             crate::progenitor_support::encode_path(&user_id.to_string()),
-            query
+            query_
         );
 
         self.client.delete(&url, None).await
@@ -299,32 +285,25 @@ impl Users {
      *  
      *  `11` — Phone number</br>`21` — WeChat</br>`23` — Alipay.
      */
-    pub async fn user_update(
+    pub async fn update(
         &self,
         user_id: &str,
         login_type: crate::types::LoginType,
         body: &crate::types::UserUpdate,
     ) -> Result<()> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("login_type={}", login_type));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !login_type.to_string().is_empty() {
+            query_args.push(("login_type".to_string(), login_type.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/users/{}?{}",
             crate::progenitor_support::encode_path(&user_id.to_string()),
-            query
+            query_
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -340,7 +319,7 @@ impl Users {
      *
      *
      */
-    pub async fn user_zak(&self) -> Result<crate::types::UserZakResponse> {
+    pub async fn zak(&self) -> Result<crate::types::UserZakResponse> {
         let url = "/users/me/zak".to_string();
         self.client.get(&url, None).await
     }
@@ -364,7 +343,7 @@ impl Users {
      *
      * * `user_id: &str` -- The user ID or email address of the user. For user-level apps, pass `me` as the value for userId.
      */
-    pub async fn user_assistant(&self, user_id: &str) -> Result<crate::types::UserAssistantsList> {
+    pub async fn assistant(&self, user_id: &str) -> Result<crate::types::UserAssistantsList> {
         let url = format!(
             "/users/{}/assistants",
             crate::progenitor_support::encode_path(&user_id.to_string()),
@@ -392,7 +371,7 @@ impl Users {
      *
      * * `user_id: &str` -- The user ID or email address of the user. For user-level apps, pass `me` as the value for userId.
      */
-    pub async fn user_assistant_create(
+    pub async fn assistant_create(
         &self,
         user_id: &str,
         body: &crate::types::UserAssistantsList,
@@ -403,10 +382,7 @@ impl Users {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -429,7 +405,7 @@ impl Users {
      *
      * * `user_id: &str` -- The user ID or email address of the user. For user-level apps, pass `me` as the value for userId.
      */
-    pub async fn user_assistants_delete(&self, user_id: &str) -> Result<()> {
+    pub async fn assistants_delete(&self, user_id: &str) -> Result<()> {
         let url = format!(
             "/users/{}/assistants",
             crate::progenitor_support::encode_path(&user_id.to_string()),
@@ -458,7 +434,7 @@ impl Users {
      * * `user_id: &str` -- The user ID or email address of the user. For user-level apps, pass `me` as the value for userId.
      * * `assistant_id: &str` -- User's first name.
      */
-    pub async fn user_assistant_delete(&self, user_id: &str, assistant_id: &str) -> Result<()> {
+    pub async fn assistant_delete(&self, user_id: &str, assistant_id: &str) -> Result<()> {
         let url = format!(
             "/users/{}/assistants/{}",
             crate::progenitor_support::encode_path(&user_id.to_string()),
@@ -486,7 +462,7 @@ impl Users {
      *
      * * `user_id: &str` -- The user ID or email address of the user. For user-level apps, pass `me` as the value for userId.
      */
-    pub async fn user_scheduler(&self, user_id: &str) -> Result<crate::types::UserSchedulersList> {
+    pub async fn scheduler(&self, user_id: &str) -> Result<crate::types::UserSchedulersList> {
         let url = format!(
             "/users/{}/schedulers",
             crate::progenitor_support::encode_path(&user_id.to_string()),
@@ -513,7 +489,7 @@ impl Users {
      *
      * * `user_id: &str` -- The user ID or email address of the user. For user-level apps, pass `me` as the value for userId.
      */
-    pub async fn user_schedulers_delete(&self, user_id: &str) -> Result<()> {
+    pub async fn schedulers_delete(&self, user_id: &str) -> Result<()> {
         let url = format!(
             "/users/{}/schedulers",
             crate::progenitor_support::encode_path(&user_id.to_string()),
@@ -541,7 +517,7 @@ impl Users {
      * * `user_id: &str` -- The user ID or email address of the user. For user-level apps, pass `me` as the value for userId.
      * * `scheduler_id: &str` -- User's first name.
      */
-    pub async fn user_scheduler_delete(&self, user_id: &str, scheduler_id: &str) -> Result<()> {
+    pub async fn scheduler_delete(&self, user_id: &str, scheduler_id: &str) -> Result<()> {
         let url = format!(
             "/users/{}/schedulers/{}",
             crate::progenitor_support::encode_path(&user_id.to_string()),
@@ -566,7 +542,7 @@ impl Users {
      *
      * * `user_id: &str` -- The user ID or email address of the user. For user-level apps, pass `me` as the value for userId.
      */
-    pub async fn user_picture(&self, user_id: &str) -> Result<()> {
+    pub async fn picture(&self, user_id: &str) -> Result<()> {
         let url = format!(
             "/users/{}/picture",
             crate::progenitor_support::encode_path(&user_id.to_string()),
@@ -607,30 +583,31 @@ impl Users {
      *   }
      *   <br>You can provide multiple values by separating them with commas(example: "host_video,participant_video”).
      */
-    pub async fn user_settings_domains(
+    pub async fn settings_domains(
         &self,
         user_id: &str,
         login_type: crate::types::LoginType,
         option: crate::types::OptionData,
         custom_query_fields: &str,
     ) -> Result<crate::types::Domains> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !custom_query_fields.is_empty() {
-            query_args.push(format!("custom_query_fields={}", custom_query_fields));
+            query_args.push((
+                "custom_query_fields".to_string(),
+                custom_query_fields.to_string(),
+            ));
         }
-        query_args.push(format!("login_type={}", login_type));
-        query_args.push(format!("option={}", option));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !login_type.to_string().is_empty() {
+            query_args.push(("login_type".to_string(), login_type.to_string()));
         }
+        if !option.to_string().is_empty() {
+            query_args.push(("option".to_string(), option.to_string()));
+        }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/users/{}/settings?{}",
             crate::progenitor_support::encode_path(&user_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -668,30 +645,31 @@ impl Users {
      *   }
      *   <br>You can provide multiple values by separating them with commas(example: "host_video,participant_video”).
      */
-    pub async fn user_settings(
+    pub async fn settings_user(
         &self,
         user_id: &str,
         login_type: crate::types::LoginType,
         option: crate::types::OptionData,
         custom_query_fields: &str,
     ) -> Result<crate::types::UserSettings> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !custom_query_fields.is_empty() {
-            query_args.push(format!("custom_query_fields={}", custom_query_fields));
+            query_args.push((
+                "custom_query_fields".to_string(),
+                custom_query_fields.to_string(),
+            ));
         }
-        query_args.push(format!("login_type={}", login_type));
-        query_args.push(format!("option={}", option));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !login_type.to_string().is_empty() {
+            query_args.push(("login_type".to_string(), login_type.to_string()));
         }
+        if !option.to_string().is_empty() {
+            query_args.push(("option".to_string(), option.to_string()));
+        }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/users/{}/settings?{}",
             crate::progenitor_support::encode_path(&user_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -729,30 +707,31 @@ impl Users {
      *   }
      *   <br>You can provide multiple values by separating them with commas(example: "host_video,participant_video”).
      */
-    pub async fn user_settings_meeting_security(
+    pub async fn settings_meeting_security(
         &self,
         user_id: &str,
         login_type: crate::types::LoginType,
         option: crate::types::OptionData,
         custom_query_fields: &str,
     ) -> Result<crate::types::MeetingSecuritySettings> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !custom_query_fields.is_empty() {
-            query_args.push(format!("custom_query_fields={}", custom_query_fields));
+            query_args.push((
+                "custom_query_fields".to_string(),
+                custom_query_fields.to_string(),
+            ));
         }
-        query_args.push(format!("login_type={}", login_type));
-        query_args.push(format!("option={}", option));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !login_type.to_string().is_empty() {
+            query_args.push(("login_type".to_string(), login_type.to_string()));
         }
+        if !option.to_string().is_empty() {
+            query_args.push(("option".to_string(), option.to_string()));
+        }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/users/{}/settings?{}",
             crate::progenitor_support::encode_path(&user_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -790,30 +769,31 @@ impl Users {
      *   }
      *   <br>You can provide multiple values by separating them with commas(example: "host_video,participant_video”).
      */
-    pub async fn user_setting(
+    pub async fn setting(
         &self,
         user_id: &str,
         login_type: crate::types::LoginType,
         option: crate::types::OptionData,
         custom_query_fields: &str,
     ) -> Result<crate::types::UserSettingsResponseOneOf> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !custom_query_fields.is_empty() {
-            query_args.push(format!("custom_query_fields={}", custom_query_fields));
+            query_args.push((
+                "custom_query_fields".to_string(),
+                custom_query_fields.to_string(),
+            ));
         }
-        query_args.push(format!("login_type={}", login_type));
-        query_args.push(format!("option={}", option));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !login_type.to_string().is_empty() {
+            query_args.push(("login_type".to_string(), login_type.to_string()));
         }
+        if !option.to_string().is_empty() {
+            query_args.push(("option".to_string(), option.to_string()));
+        }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/users/{}/settings?{}",
             crate::progenitor_support::encode_path(&user_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -833,32 +813,25 @@ impl Users {
      * * `option: crate::types::UserSettingsUpdateOption`
      * * `user_id: &str` -- The user ID or email address of the user. For user-level apps, pass `me` as the value for userId.
      */
-    pub async fn user_settings_update(
+    pub async fn settings_update(
         &self,
         option: crate::types::UserSettingsUpdateOption,
         user_id: &str,
         body: &crate::types::UserSettingsUpdateRequestOneOf,
     ) -> Result<()> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("option={}", option));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !option.to_string().is_empty() {
+            query_args.push(("option".to_string(), option.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/users/{}/settings?{}",
             crate::progenitor_support::encode_path(&user_id.to_string()),
-            query
+            query_
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -877,7 +850,7 @@ impl Users {
      *
      * * `user_id: &str` -- The user ID or email address of the user. For user-level apps, pass `me` as the value for userId.
      */
-    pub async fn user_status(
+    pub async fn status(
         &self,
         user_id: &str,
         body: &crate::types::UserStatusRequest,
@@ -888,10 +861,7 @@ impl Users {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -913,7 +883,7 @@ impl Users {
      *
      * * `user_id: &str` -- The user ID or email address of the user. For user-level apps, pass `me` as the value for userId.
      */
-    pub async fn user_password(
+    pub async fn password(
         &self,
         user_id: &str,
         body: &crate::types::UserPasswordRequest,
@@ -924,10 +894,7 @@ impl Users {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -946,7 +913,7 @@ impl Users {
      *
      * * `user_id: &str` -- The user ID or email address of the user. For user-level apps, pass `me` as the value for userId.
      */
-    pub async fn user_permission(&self, user_id: &str) -> Result<crate::types::UserPermissions> {
+    pub async fn permission(&self, user_id: &str) -> Result<crate::types::UserPermissions> {
         let url = format!(
             "/users/{}/permissions",
             crate::progenitor_support::encode_path(&user_id.to_string()),
@@ -972,28 +939,24 @@ impl Users {
      * * `type_: crate::types::UserTokenType` -- User token types:<br>`token` - Used for starting meetings with the client SDK. This token expires in 14 days and a new token will be returned after the expiry.<br>`zak` - Used for generating the start meeting URL. The token expiration time is two hours. For API users, the expiration time is 90 days.
      * * `ttl: i64` -- Use this field in conjunction with the `type` field where the value of `type` field is `zak`. The value of this field denotes the expiry time of the `zak` token in seconds. For example, if you would like the zak token to be expired after one hour of the token generation, the value of this field should be `3600`.
      */
-    pub async fn user_token(
+    pub async fn token(
         &self,
         user_id: &str,
         type_: crate::types::UserTokenType,
         ttl: i64,
     ) -> Result<crate::types::UserZakResponse> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if ttl > 0 {
-            query_args.push(format!("ttl={}", ttl));
+            query_args.push(("ttl".to_string(), ttl.to_string()));
         }
-        query_args.push(format!("type={}", type_));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !type_.to_string().is_empty() {
+            query_args.push(("type".to_string(), type_.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/users/{}/token?{}",
             crate::progenitor_support::encode_path(&user_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -1014,7 +977,7 @@ impl Users {
      *
      * * `user_id: &str` -- The user ID or email address of the user. For user-level apps, pass `me` as the value for userId.
      */
-    pub async fn user_sso_token_delete(&self, user_id: &str) -> Result<()> {
+    pub async fn sso_token_delete(&self, user_id: &str) -> Result<()> {
         let url = format!(
             "/users/{}/token",
             crate::progenitor_support::encode_path(&user_id.to_string()),
@@ -1041,19 +1004,13 @@ impl Users {
      *
      * * `email: &str` -- The email address to be verified.
      */
-    pub async fn user_email(&self, email: &str) -> Result<crate::types::UserEmailResponse> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+    pub async fn email(&self, email: &str) -> Result<crate::types::UserEmailResponse> {
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !email.is_empty() {
-            query_args.push(format!("email={}", email));
+            query_args.push(("email".to_string(), email.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/users/email?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/users/email?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -1078,21 +1035,14 @@ impl Users {
      *
      * * `user_id: &str` -- The user ID or email address of the user. For user-level apps, pass `me` as the value for userId.
      */
-    pub async fn user_email_update(
-        &self,
-        user_id: &str,
-        body: &crate::types::Members,
-    ) -> Result<()> {
+    pub async fn email_update(&self, user_id: &str, body: &crate::types::Members) -> Result<()> {
         let url = format!(
             "/users/{}/email",
             crate::progenitor_support::encode_path(&user_id.to_string()),
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -1111,22 +1061,16 @@ impl Users {
      *
      * * `vanity_name: &str` -- Personal meeting room name.
      */
-    pub async fn user_vanity_name(
+    pub async fn vanity_name(
         &self,
         vanity_name: &str,
     ) -> Result<crate::types::UserVanityNameResponse> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !vanity_name.is_empty() {
-            query_args.push(format!("vanity_name={}", vanity_name));
+            query_args.push(("vanity_name".to_string(), vanity_name.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/users/vanity_name?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/users/vanity_name?{}", query_);
 
         self.client.get(&url, None).await
     }
@@ -1155,7 +1099,7 @@ impl Users {
      *
      * * `account_id: &str` -- User's first name.
      */
-    pub async fn switch_user_account(
+    pub async fn switch_account(
         &self,
         account_id: &str,
         user_id: &str,
@@ -1168,10 +1112,7 @@ impl Users {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -1208,10 +1149,7 @@ impl Users {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -1245,10 +1183,7 @@ impl Users {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -1269,22 +1204,16 @@ impl Users {
      * * `file_ids: &str` -- Provide the id of the file that is to be deleted. To delete multiple files, provide comma separated values for this field.
      * * `user_id: &str` -- Unique identifier of the user. Retrieve the value of this field by calling the [List users](https://marketplace.zoom.us/docs/api-reference/zoom-api/users/users) API. .
      */
-    pub async fn del_user_vb(&self, user_id: &str, file_ids: &str) -> Result<()> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+    pub async fn del_vb(&self, user_id: &str, file_ids: &str) -> Result<()> {
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !file_ids.is_empty() {
-            query_args.push(format!("file_ids={}", file_ids));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("file_ids".to_string(), file_ids.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/users/{}/settings/virtual_backgrounds?{}",
             crate::progenitor_support::encode_path(&user_id.to_string()),
-            query
+            query_
         );
 
         self.client.delete(&url, None).await
