@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct Webinars {
-    client: Client,
+    pub client: Client,
 }
 
 impl Webinars {
@@ -41,24 +41,18 @@ impl Webinars {
         page_size: i64,
         page_number: i64,
     ) -> Result<crate::types::Domains> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page_number > 0 {
-            query_args.push(format!("page_number={}", page_number));
+            query_args.push(("page_number".to_string(), page_number.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("page_size".to_string(), page_size.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/users/{}/webinars?{}",
             crate::progenitor_support::encode_path(&user_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -82,10 +76,7 @@ impl Webinars {
      *
      * * `user_id: &str` -- The user ID or email address of the user. For user-level apps, pass `me` as the value for userId.
      */
-    pub async fn webinar_create(
-        &self,
-        user_id: &str,
-    ) -> Result<crate::types::WebinarCreateResponseAllOf> {
+    pub async fn create(&self, user_id: &str) -> Result<crate::types::WebinarCreateResponseAllOf> {
         let url = format!(
             "/users/{}/webinars",
             crate::progenitor_support::encode_path(&user_id.to_string()),
@@ -116,27 +107,21 @@ impl Webinars {
         occurrence_id: &str,
         show_previous_occurrences: bool,
     ) -> Result<crate::types::WebinarResponseAllOf> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !occurrence_id.is_empty() {
-            query_args.push(format!("occurrence_id={}", occurrence_id));
+            query_args.push(("occurrence_id".to_string(), occurrence_id.to_string()));
         }
         if show_previous_occurrences {
-            query_args.push(format!(
-                "show_previous_occurrences={}",
-                show_previous_occurrences
+            query_args.push((
+                "show_previous_occurrences".to_string(),
+                show_previous_occurrences.to_string(),
             ));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/webinars/{}?{}",
             crate::progenitor_support::encode_path(&webinar_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -164,33 +149,27 @@ impl Webinars {
      *   
      *   The default value of this field is `false`.
      */
-    pub async fn webinar_delete(
+    pub async fn delete(
         &self,
         webinar_id: i64,
         occurrence_id: &str,
         cancel_webinar_reminder: &str,
     ) -> Result<()> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !cancel_webinar_reminder.is_empty() {
-            query_args.push(format!(
-                "cancel_webinar_reminder={}",
-                cancel_webinar_reminder
+            query_args.push((
+                "cancel_webinar_reminder".to_string(),
+                cancel_webinar_reminder.to_string(),
             ));
         }
         if !occurrence_id.is_empty() {
-            query_args.push(format!("occurrence_id={}", occurrence_id));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("occurrence_id".to_string(), occurrence_id.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/webinars/{}?{}",
             crate::progenitor_support::encode_path(&webinar_id.to_string()),
-            query
+            query_
         );
 
         self.client.delete(&url, None).await
@@ -214,22 +193,16 @@ impl Webinars {
      * * `webinar_id: i64` -- The webinar ID in "**long**" format(represented as int64 data type in JSON). .
      * * `occurrence_id: &str` -- Webinar occurrence id. Support change of agenda, start_time, duration, settings: {host_video, panelist_video, hd_video, watermark, auto_recording}.
      */
-    pub async fn webinar_update(&self, webinar_id: i64, occurrence_id: &str) -> Result<()> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+    pub async fn update(&self, webinar_id: i64, occurrence_id: &str) -> Result<()> {
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !occurrence_id.is_empty() {
-            query_args.push(format!("occurrence_id={}", occurrence_id));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("occurrence_id".to_string(), occurrence_id.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/webinars/{}?{}",
             crate::progenitor_support::encode_path(&webinar_id.to_string()),
-            query
+            query_
         );
 
         self.client.patch(&url, None).await
@@ -258,34 +231,28 @@ impl Webinars {
      * * `page_size: i64` -- The number of records returned within a single API call.
      * * `next_page_token: &str` -- The next page token is used to paginate through large result sets. A next page token will be returned whenever the set of available results exceeds the current page size. The expiration period for this token is 15 minutes.
      */
-    pub async fn list_webinar_participants(
+    pub async fn list_participants(
         &self,
         webinar_id: &str,
         page_size: i64,
         next_page_token: &str,
     ) -> Result<Vec<crate::types::Participants>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !next_page_token.is_empty() {
-            query_args.push(format!("next_page_token={}", next_page_token));
+            query_args.push(("next_page_token".to_string(), next_page_token.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("page_size".to_string(), page_size.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/past_webinars/{}/participants?{}",
             crate::progenitor_support::encode_path(&webinar_id.to_string()),
-            query
+            query_
         );
 
         let resp: crate::types::ListWebinarParticipantsResponse =
-            self.client.get(&url, None).await.unwrap();
+            self.client.get(&url, None).await?;
 
         // Return our response data.
         Ok(resp.participants)
@@ -296,7 +263,7 @@ impl Webinars {
      *
      * This function performs a `GET` to the `/past_webinars/{webinarId}/participants` endpoint.
      *
-     * As opposed to `list_webinar_participants`, this function returns all the pages of the request at once.
+     * As opposed to `list_participants`, this function returns all the pages of the request at once.
      *
      * Use this API to list all the participants who attended a webinar hosted in the past. <br>
      *
@@ -310,7 +277,7 @@ impl Webinars {
      *
      *
      */
-    pub async fn list_all_webinar_participants(
+    pub async fn list_all_participants(
         &self,
         webinar_id: &str,
     ) -> Result<Vec<crate::types::Participants>> {
@@ -320,7 +287,7 @@ impl Webinars {
         );
 
         let mut resp: crate::types::ListWebinarParticipantsResponse =
-            self.client.get(&url, None).await.unwrap();
+            self.client.get(&url, None).await?;
 
         let mut participants = resp.participants;
         let mut page = resp.next_page_token;
@@ -332,14 +299,12 @@ impl Webinars {
                 resp = self
                     .client
                     .get(&format!("{}?next_page_token={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             } else {
                 resp = self
                     .client
                     .get(&format!("{}&next_page_token={}", url, page), None)
-                    .await
-                    .unwrap();
+                    .await?;
             }
 
             participants.append(&mut resp.participants);
@@ -371,7 +336,7 @@ impl Webinars {
      *
      * * `webinar_id: i64` -- The webinar ID in "**long**" format(represented as int64 data type in JSON). .
      */
-    pub async fn webinar_status(
+    pub async fn status(
         &self,
         webinar_id: i64,
         body: &crate::types::WebinarStatusRequest,
@@ -382,10 +347,7 @@ impl Webinars {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -407,7 +369,7 @@ impl Webinars {
      *
      * * `webinar_id: i64` -- The webinar ID in "**long**" format(represented as int64 data type in JSON). .
      */
-    pub async fn webinar_panelist(&self, webinar_id: i64) -> Result<crate::types::Domains> {
+    pub async fn panelist(&self, webinar_id: i64) -> Result<crate::types::Domains> {
         let url = format!(
             "/webinars/{}/panelists",
             crate::progenitor_support::encode_path(&webinar_id.to_string()),
@@ -433,7 +395,7 @@ impl Webinars {
      *
      * * `webinar_id: i64` -- The webinar ID in "**long**" format(represented as int64 data type in JSON). .
      */
-    pub async fn webinar_panelist_create(
+    pub async fn panelist_create(
         &self,
         webinar_id: i64,
         body: &crate::types::WebinarPanelist,
@@ -444,10 +406,7 @@ impl Webinars {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -467,7 +426,7 @@ impl Webinars {
      *
      * * `webinar_id: i64` -- The webinar ID in "**long**" format(represented as int64 data type in JSON). .
      */
-    pub async fn webinar_panelists_delete(&self, webinar_id: i64) -> Result<()> {
+    pub async fn panelists_delete(&self, webinar_id: i64) -> Result<()> {
         let url = format!(
             "/webinars/{}/panelists",
             crate::progenitor_support::encode_path(&webinar_id.to_string()),
@@ -495,7 +454,7 @@ impl Webinars {
      * * `webinar_id: i64` -- The webinar ID in "**long**" format(represented as int64 data type in JSON). .
      * * `panelist_id: i64` -- The panelist ID or panelist email.
      */
-    pub async fn webinar_panelist_delete(&self, webinar_id: i64, panelist_id: i64) -> Result<()> {
+    pub async fn panelist_delete(&self, webinar_id: i64, panelist_id: i64) -> Result<()> {
         let url = format!(
             "/webinars/{}/panelists/{}",
             crate::progenitor_support::encode_path(&webinar_id.to_string()),
@@ -532,7 +491,7 @@ impl Webinars {
      *   The page number of the current page in the returned records.
      * * `next_page_token: &str` -- The next page token is used to paginate through large result sets. A next page token will be returned whenever the set of available results exceeds the current page size. The expiration period for this token is 15 minutes.
      */
-    pub async fn webinar_registrant(
+    pub async fn registrant(
         &self,
         webinar_id: &str,
         occurrence_id: &str,
@@ -542,34 +501,33 @@ impl Webinars {
         page_number: i64,
         next_page_token: &str,
     ) -> Result<crate::types::Domains> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !next_page_token.is_empty() {
-            query_args.push(format!("next_page_token={}", next_page_token));
+            query_args.push(("next_page_token".to_string(), next_page_token.to_string()));
         }
         if !occurrence_id.is_empty() {
-            query_args.push(format!("occurrence_id={}", occurrence_id));
+            query_args.push(("occurrence_id".to_string(), occurrence_id.to_string()));
         }
         if page_number > 0 {
-            query_args.push(format!("page_number={}", page_number));
+            query_args.push(("page_number".to_string(), page_number.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
+            query_args.push(("page_size".to_string(), page_size.to_string()));
+        }
+        if !status.to_string().is_empty() {
+            query_args.push(("status".to_string(), status.to_string()));
         }
-        query_args.push(format!("status={}", status));
         if !tracking_source_id.is_empty() {
-            query_args.push(format!("tracking_source_id={}", tracking_source_id));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push((
+                "tracking_source_id".to_string(),
+                tracking_source_id.to_string(),
+            ));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/webinars/{}/registrants?{}",
             crate::progenitor_support::encode_path(&webinar_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -592,26 +550,20 @@ impl Webinars {
      * * `webinar_id: i64` -- The webinar ID in "**long**" format(represented as int64 data type in JSON). .
      * * `occurrence_ids: &str` -- Occurrence ID. Get this value from the webinar get API. Multiple values separated by a comma.
      */
-    pub async fn webinar_registrant_create(
+    pub async fn registrant_create(
         &self,
         webinar_id: &str,
         occurrence_ids: &str,
     ) -> Result<crate::types::WebinarRegistrantCreateResponse> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !occurrence_ids.is_empty() {
-            query_args.push(format!("occurrence_ids={}", occurrence_ids));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("occurrence_ids".to_string(), occurrence_ids.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/webinars/{}/registrants?{}",
             crate::progenitor_support::encode_path(&webinar_id.to_string()),
-            query
+            query_
         );
 
         self.client.post(&url, None).await
@@ -642,7 +594,7 @@ impl Webinars {
      *
      * * `webinar_id: &str` -- Unique identifier of the webinar.
      */
-    pub async fn add_batch_webinar_registrants(
+    pub async fn add_batch_registrants(
         &self,
         webinar_id: &str,
         body: &crate::types::AddBatchRegistrantsRequest,
@@ -653,10 +605,7 @@ impl Webinars {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -677,34 +626,25 @@ impl Webinars {
      * * `webinar_id: i64` -- The webinar ID in "**long**" format(represented as int64 data type in JSON). .
      * * `occurrence_id: &str` -- The meeting occurrence ID.
      */
-    pub async fn webinar_registrant_status(
+    pub async fn registrant_status(
         &self,
         webinar_id: i64,
         occurrence_id: &str,
         body: &crate::types::RegistrantStatus,
     ) -> Result<()> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !occurrence_id.is_empty() {
-            query_args.push(format!("occurrence_id={}", occurrence_id));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("occurrence_id".to_string(), occurrence_id.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/webinars/{}/registrants/status?{}",
             crate::progenitor_support::encode_path(&webinar_id.to_string()),
-            query
+            query_
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -749,7 +689,7 @@ impl Webinars {
      *
      * * `webinar_id: i64` -- The webinar ID in "**long**" format(represented as int64 data type in JSON). .
      */
-    pub async fn webinar_poll(&self, webinar_id: i64) -> Result<crate::types::Domains> {
+    pub async fn poll(&self, webinar_id: i64) -> Result<crate::types::Domains> {
         let url = format!(
             "/webinars/{}/polls",
             crate::progenitor_support::encode_path(&webinar_id.to_string()),
@@ -774,7 +714,7 @@ impl Webinars {
      *
      * * `webinar_id: i64` -- The webinar ID in "**long**" format(represented as int64 data type in JSON). .
      */
-    pub async fn webinar_poll_create(
+    pub async fn poll_create(
         &self,
         webinar_id: i64,
         body: &crate::types::Poll,
@@ -785,10 +725,7 @@ impl Webinars {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -809,7 +746,7 @@ impl Webinars {
      * * `webinar_id: i64` -- The webinar ID in "**long**" format(represented as int64 data type in JSON). .
      * * `poll_id: &str` -- User's first name.
      */
-    pub async fn webinar_poll_get(
+    pub async fn poll_get(
         &self,
         webinar_id: i64,
         poll_id: &str,
@@ -840,7 +777,7 @@ impl Webinars {
      * * `webinar_id: i64` -- The webinar ID in "**long**" format(represented as int64 data type in JSON). .
      * * `poll_id: &str` -- User's first name.
      */
-    pub async fn webinar_poll_update(
+    pub async fn poll_update(
         &self,
         webinar_id: i64,
         poll_id: &str,
@@ -853,10 +790,7 @@ impl Webinars {
         );
 
         self.client
-            .put(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .put(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -877,7 +811,7 @@ impl Webinars {
      * * `webinar_id: i64` -- The webinar ID in "**long**" format(represented as int64 data type in JSON). .
      * * `poll_id: &str` -- User's first name.
      */
-    pub async fn webinar_poll_delete(&self, webinar_id: i64, poll_id: &str) -> Result<()> {
+    pub async fn poll_delete(&self, webinar_id: i64, poll_id: &str) -> Result<()> {
         let url = format!(
             "/webinars/{}/polls/{}",
             crate::progenitor_support::encode_path(&webinar_id.to_string()),
@@ -905,7 +839,7 @@ impl Webinars {
      *
      * * `webinar_id: i64` -- The webinar ID in "**long**" format(represented as int64 data type in JSON). .
      */
-    pub async fn webinar_registrants_questions_get(
+    pub async fn registrants_questions_get(
         &self,
         webinar_id: i64,
     ) -> Result<crate::types::WebinarRegistrantQuestions> {
@@ -936,7 +870,7 @@ impl Webinars {
      *
      * * `webinar_id: i64` -- The webinar ID in "**long**" format(represented as int64 data type in JSON). .
      */
-    pub async fn webinar_registrant_question_update(
+    pub async fn registrant_question_update(
         &self,
         webinar_id: i64,
         body: &crate::types::WebinarRegistrantQuestions,
@@ -947,10 +881,7 @@ impl Webinars {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -972,28 +903,22 @@ impl Webinars {
      * * `registrant_id: &str` -- User's first name.
      * * `occurrence_id: &str` -- The meeting occurrence ID.
      */
-    pub async fn webinar_registrant_get(
+    pub async fn registrant_get(
         &self,
         webinar_id: &str,
         registrant_id: &str,
         occurrence_id: &str,
     ) -> Result<crate::types::Domains> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !occurrence_id.is_empty() {
-            query_args.push(format!("occurrence_id={}", occurrence_id));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("occurrence_id".to_string(), occurrence_id.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/webinars/{}/registrants/{}?{}",
             crate::progenitor_support::encode_path(&webinar_id.to_string()),
             crate::progenitor_support::encode_path(&registrant_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -1015,28 +940,22 @@ impl Webinars {
      * * `registrant_id: &str` -- User's first name.
      * * `occurrence_id: &str` -- The webinar occurence ID.
      */
-    pub async fn delete_webinar_registrant(
+    pub async fn delete_registrant(
         &self,
         webinar_id: &str,
         registrant_id: &str,
         occurrence_id: &str,
     ) -> Result<()> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !occurrence_id.is_empty() {
-            query_args.push(format!("occurrence_id={}", occurrence_id));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("occurrence_id".to_string(), occurrence_id.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/webinars/{}/registrants/{}?{}",
             crate::progenitor_support::encode_path(&webinar_id.to_string()),
             crate::progenitor_support::encode_path(&registrant_id.to_string()),
-            query
+            query_
         );
 
         self.client.delete(&url, None).await
@@ -1058,34 +977,28 @@ impl Webinars {
      * * `next_page_token: &str` -- The next page token is used to paginate through large result sets. A next page token will be returned whenever the set of available results exceeds the current page size. The expiration period for this token is 15 minutes.
      * * `webinar: &str` -- The Webinar UUID. Each Webinar instance will generate its own Webinar UUID (i.e., after a Webinar ends, a new UUID will be generated for the next instance of the Webinar). Please double encode your UUID when using it for API calls if the UUID begins with a '/' or contains '//' in it.
      */
-    pub async fn webinar_absentee(
+    pub async fn absentee(
         &self,
         occurrence_id: &str,
         page_size: i64,
         next_page_token: &str,
         webinar_uuid: &str,
     ) -> Result<crate::types::Domains> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !next_page_token.is_empty() {
-            query_args.push(format!("next_page_token={}", next_page_token));
+            query_args.push(("next_page_token".to_string(), next_page_token.to_string()));
         }
         if !occurrence_id.is_empty() {
-            query_args.push(format!("occurrence_id={}", occurrence_id));
+            query_args.push(("occurrence_id".to_string(), occurrence_id.to_string()));
         }
         if page_size > 0 {
-            query_args.push(format!("page_size={}", page_size));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("page_size".to_string(), page_size.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/past_webinars/{}/absentees?{}",
             crate::progenitor_support::encode_path(&webinar_uuid.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -1141,7 +1054,7 @@ impl Webinars {
      *   
      *   If a UUID starts with "/" or contains "//" (example: "/ajXp112QmuoKj4854875==\"), you must **double encode** the UUID before making an API request.
      */
-    pub async fn list_past_webinar_poll_results(
+    pub async fn list_past_poll_results(
         &self,
         webinar_id: &str,
     ) -> Result<crate::types::ReportMeetingPollsResponse> {
@@ -1175,7 +1088,7 @@ impl Webinars {
      *   
      *   If a UUID starts with "/" or contains "//" (example: "/ajXp112QmuoKj4854875==\"), you must **double encode** the UUID before making an API request.
      */
-    pub async fn list_past_webinar_qa(
+    pub async fn list_past_qa(
         &self,
         webinar_id: &str,
     ) -> Result<crate::types::ReportWebinarQaResponse> {
@@ -1199,7 +1112,7 @@ impl Webinars {
      * **Prerequisites:**
      * * Pro or a higher account with Webinar plan enabled.
      */
-    pub async fn list_webinar_templates(
+    pub async fn list_templates(
         &self,
         user_id: &str,
     ) -> Result<crate::types::ListWebinarTemplatesResponse> {
@@ -1231,7 +1144,7 @@ impl Webinars {
      *
      * * `webinar_id: &str` -- The webinar's unique ID.
      */
-    pub async fn get_webinar_live_stream_details(
+    pub async fn get_live_stream_details(
         &self,
         webinar_id: &str,
     ) -> Result<crate::types::GetLiveStreamDetailsResponse> {
@@ -1262,7 +1175,7 @@ impl Webinars {
      *
      * * `webinar_id: i64` -- The webinar ID in "**long**" format(represented as int64 data type in JSON). .
      */
-    pub async fn webinar_live_stream_update(
+    pub async fn live_stream_update(
         &self,
         webinar_id: &str,
         body: &crate::types::MeetingLiveStream,
@@ -1273,10 +1186,7 @@ impl Webinars {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -1298,7 +1208,7 @@ impl Webinars {
      *
      * * `webinar_id: i64` -- The webinar ID in "**long**" format(represented as int64 data type in JSON). .
      */
-    pub async fn webinar_live_stream_status_update(
+    pub async fn live_stream_status_update(
         &self,
         webinar_id: i64,
         body: &crate::types::WebinarLiveStreamStatus,
@@ -1309,10 +1219,7 @@ impl Webinars {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -1333,7 +1240,7 @@ impl Webinars {
      *
      * * `webinar_id: i64` -- The webinar ID in "**long**" format(represented as int64 data type in JSON). .
      */
-    pub async fn webinar_invite_links_create(
+    pub async fn invite_links_create(
         &self,
         webinar_id: i64,
         body: &crate::types::InviteLink,
@@ -1344,10 +1251,7 @@ impl Webinars {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 }
